<?php
/**
 * Defines plugin options.
 *
 * Format:
 *  'default':  Default option value.           If not set, equals false.
 *  'autoload': Whether to autoload the option. If not set, equals true.
 *
 * @package First-Party-Analytics
 */

$default_sources = [
    __( 'Animation and Comics', 'first-party-analytics' )  => [
        'Bilibili' => [
            [ 'Bilibili', 'bilibili.com' ],
        ],
    ],
    __( 'Other Arts and Entertainment', 'first-party-analytics' ) => [
        'Fandom' => [
            [ 'Fandom', 'fandom.com' ],
        ],
    ],
    __( 'Streaming & Online TV', 'first-party-analytics' ) => [
        'YouTube' => [
            [ 'YouTube', 'youtube.com' ],
        ],
        'Netflix' => [
            [ 'Netflix', 'netflix.com' ],
        ],
    ],
    __( 'Consumer Electronics', 'first-party-analytics' )  => [
        'Samsung' => [
            [ 'Samsung', 'samsung.com' ],
        ],
    ],
    __( 'Email', 'first-party-analytics' )                 => [
        'Live'    => [
            [ 'Live', 'live.com' ],
        ],
        'Mail.Ru' => [
            [ 'Mail.Ru', 'mail.ru' ],
        ],
    ],
    __( 'Electronics and Technology', 'first-party-analytics' ) => [
        'Zoom' => [
            [ 'Zoom', 'zoom.us' ],
        ],
    ],
    __( 'Programming and Developer Software', 'first-party-analytics' ) => [
        'Office'           => [
            [ 'Office', 'office.com' ],
        ],
        'Microsoft Online' => [
            [ 'Microsoft Online', 'microsoftonline.com' ],
        ],
        'Microsoft'        => [
            [ 'Microsoft', 'microsoft.com' ],
        ],
    ],
    __( 'Search Engines', 'first-party-analytics' )        => [
        'Google'     => [
            [ 'Google', 'google.*' ],
        ],
        'Baidu'      => [
            [ 'Baidu', 'baidu.*' ],
        ],
        'Yandex'     => [
            [ 'Yandex', 'yandex.*' ],
        ],
        'Bing'       => [
            [ 'Bing', 'bing.*' ],
        ],
        'DuckDuckGo' => [
            [ 'DuckDuckGo', 'duckduckgo.com' ],
        ],
    ],
    __( 'Social Media Networks', 'first-party-analytics' ) => [
        'Facebook'  => [
            [ 'Facebook', 'facebook.com' ],
        ],
        'Twitter'   => [
            [ 'Twitter', 'twitter.com' ],
        ],
        'Instagram' => [
            [ 'Instagram', 'instagram.com' ],
        ],
        'Whatsapp'  => [
            [ 'Whatsapp', 'whatsapp.com' ],
        ],
        'TikTok'    => [
            [ 'TikTok', 'tiktok.com' ],
        ],
        'Reddit'    => [
            [ 'Reddit', 'reddit.com' ],
        ],
        'VK'        => [
            [ 'VK', 'vk.*' ],
        ],
        'LinkedIn'  => [
            [ 'LinkedIn', 'linkedin.com' ],
        ],
        'Discord'   => [
            [ 'Discord', 'discord.com' ],
        ],
        'Pinterest' => [
            [ 'Pinterest', 'pinterest.com' ],
        ],
        'OK.ru'     => [
            [ 'OK.ru', 'ok.ru' ],
        ],
    ],
    __( 'Telecommunications', 'first-party-analytics' )    => [
        'Docomo' => [
            [ 'Docomo', 'docomo.ne.jp' ],
        ],
    ],
    __( 'eCommerce', 'first-party-analytics' )             => [
        'Amazon' => [
            [ 'Amazon', 'amazon.com' ],

        ],
        'eBay'   => [
            [ 'eBay', 'ebay.com' ],
        ],
    ],
    __( 'Video Games', 'first-party-analytics' )           => [
        'Twitch' => [
            [ 'Twitch', 'twitch.tv' ],
        ],
        'Roblox' => [
            [ 'Roblox', 'roblox.com' ],
        ],
    ],
    __( 'News & Media Publishers', 'first-party-analytics' ) => [
        'Yahoo'              => [
            [ 'Yahoo', 'yahoo.com' ],
        ],

        'Yahoo JP'           => [
            [ 'Yahoo JP', 'yahoo.co.jp' ],
        ],

        'Naver'              => [
            [ 'Naver', 'naver.com' ],
        ],

        'Yandex Turbo Pages' => [
            [ 'Yandex Turbo Pages', 'turbopages.org' ],
        ],

        'QQ'                 => [
            [ 'QQ', 'qq.com' ],
        ],

        'MSN'                => [
            [ 'MSN', 'msn.com' ],
        ],

        'Globo'              => [
            [ 'Globo', 'globo.com' ],
        ],
    ],
    __( 'Dictionaries and Encyclopedias', 'first-party-analytics' ) => [
        'Wikipedia' => [
            [ 'Wikipedia', 'wikipedia.org' ],
        ],
    ],
    __( 'Weather', 'first-party-analytics' )               => [
        'Accuweather' => [
            [ 'Accuweather', 'accuweather.com' ],
        ],
        'Weather'     => [
            [ 'Weather', 'weather.com' ],
        ],
    ],
];

function recur_ksort( &$array ) {
    foreach ( $array as &$value ) {
        if ( is_array( $value ) ) {
            recur_ksort( $value );
        }
    }
    return uksort( $array, 'strcasecmp' );
}
recur_ksort( $default_sources );

return [

    /*
     * If saffy activation was handled.
     */
    'first-party-analytics-activation-handled'           => [
        'default' => '1',
    ],

    /*
     * Decimate setting.
     */
    'first-party-analytics-setting-decimate'             => [
        'default' => 1,
    ],

    /*
     * Last handled version update.
     */
    'first-party-analytics-last-handled-version-update'  => [],

    /*
     * The name of the random image.
     */
    'first-party-analytics-random-image-name'            => [],

    /*
     * Salt for file names in temp dir.
     */
    'first-party-analytics-salt'                         => [],

    /*
     * MaxMind license key.
     */
    'first-party-analytics-maxmind-license-key'          => [
        'default' => '',
    ],

    /*
     * Exclusion cookies.
     *
     * Do not save tracking data for the users with these cookies.
     */
    'first-party-analytics-setting-exclusion-cookies'    => [
        'default' => [],
    ],

    /*
     * Exclusion IPs.
     *
     * Do not save tracking data for the users with these IPs (can also be a range).
     */
    'first-party-analytics-setting-exclusion-ips'        => [
        'default' => [],
    ],

    /*
     * Use object cache, when it's available.
     */
    'first-party-analytics-setting-use-object-cache'     => [
        'autoload' => false,
        'default'  => '1',
    ],

    /*
     * Add "ping" attribute to links.
     */
    'first-party-analytics-setting-add-ping-attribute'   => [
        'autoload' => false,
        'default'  => '',
    ],

    /*
     * Raw requests. Used for percentiles calculation.
     *
     * @see Raw_Analytics_Data::EXTRA_FILE_LINES_LIMIT const
     * for the more detailed description of the purpose of this option.
     */
    'first-party-analytics-raw-requests'                 => [
        'autoload' => false,
        'default'  => [],
    ],

    /*
     * Sources.
     */
    'first-party-analytics-setting-sources'              => [
        'autoload' => false,
        'default'  => $default_sources,
    ],

    /*
     * An array of completed order counts.
     *
     * Where key is revision ID (or 0 if the data is not for any revision) and the value is completed orders count.
     */
    'first-party-analytics-completed-orders-count'       => [
        'default' => [],
    ],

    /*
     * A token for data sharing
     */
    'first-party-analytics-data-sharing-token'           => [],

    /*
     * Domain type to use (for analytics block detection).
     */
    'first-party-analytics-setting-analytics-block-detection-domain-type-to-use' => [
        'default' => 'fpa',
    ],

    /*
     * Own (CNAMEd) domain for analytics block detection.
     */
    'first-party-analytics-setting-analytics-block-detection-own-domain' => [
        'default' => home_url(),
    ],

    /*
     * Custom domain for analytics block detection.
     */
    'first-party-analytics-setting-analytics-block-detection-custom-domain' => [
        'default' => 'https://analytics.google.com',
    ],

    /*
     * Domain type to use (for analytics block detection).
     */
    'first-party-analytics-setting-ads-block-detection-domain-type-to-use' => [
        'default' => 'fpa',
    ],

    /*
     * Own (CNAMEd) domain for analytics block detection.
     */
    'first-party-analytics-setting-ads-block-detection-own-domain' => [
        'default' => home_url(),
    ],

    /*
     * Custom domain for analytics block detection.
     */
    'first-party-analytics-setting-ads-block-detection-custom-domain' => [
        'default' => 'https://ads.google.com',
    ],

    /*
     * Enable data sharing and recommendations.
     */
    'first-party-analytics-setting-enable-data-sharing-and-recommendations' => [
        'default' => '',
    ],

    /*
     * Recommendations list (to not overwrite them).
     */
    'first-party-analytics-recommendations'              => [
        'default'  => [],
        'autoload' => false,
    ],

    /*
     * The ID of the last saved recommendation
     */
    'first-party-analytics-last-saved-recommendation-id' => [
        'default'  => 0,
        'autoload' => false,
    ],

    /*
     * The last known hash of fields mapping.
     */
    'first-party-analytics-fields-mapping-last-known-hashes' => [
        'default' => [],
    ],
];
