<?php
/**
 * Non-AJAX request handlers.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\AJAX;

use Exception;
use First_Party_Analytics\Data_Sharing\Token;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\Tracking\Link_Visits as Link_Visits_Tracking;

/**
 * Manages non-AJAX requests.
 */
final class Non_AJAX_Requests {

    /**
     * Constructor.
     */
    public function __construct() {
        $this->add_listeners();
    }

    /**
     * Adds listeners.
     */
    private function add_listeners() {
        $actions = [
            'link_ping',
            'get_data_sharing_token',
        ];

        if (
            array_key_exists( 'plugin', $_REQUEST ) && 'first-party-analytics' === $_REQUEST['plugin'] && 
            array_key_exists( 'action', $_REQUEST ) && in_array( $_REQUEST['action'], $actions, true ) 
        ) {
            call_user_func( [ $this, $_REQUEST['action'] ] ); 
        }
    }

    /**
     * Link visited, a ping request.
     *
     * @throws Exception Exception.
     */
    public function link_ping() {
        if (
            isset( $_SERVER['HTTP_PING_FROM'] ) &&
            isset( $_SERVER['HTTP_PING_TO'] ) &&
            isset( $_SERVER['REQUEST_TIME'] )
        ) {
            $source  = sanitize_text_field( wp_unslash( $_SERVER['HTTP_PING_FROM'] ) );
            $href    = sanitize_text_field( wp_unslash( $_SERVER['HTTP_PING_TO'] ) );
            $time    = (int) sanitize_text_field( wp_unslash( $_SERVER['REQUEST_TIME'] ) );
            $post_id = (int) sanitize_text_field( wp_unslash( $_REQUEST['post_id'] ) ); 

            Link_Visits_Tracking::handle( $source, $href, $time, $post_id );

            wp_die();
        }
    }

    /**
     * Saves data sharing token.
     *
     * @throws Exception Exception.
     */
    public function get_data_sharing_token() {
        if ( isset( $_REQUEST['token'] ) ) { 
            $token = sanitize_text_field( wp_unslash( $_REQUEST['token'] ) ); 
            First_Party_Analytics::$options->set( Token::OPTION_NAME, $token );
        }
    }
}
