<?php
/**
 * Assets
 *
 * Main assets' handler.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Assets;

use Exception;

/**
 * Assets class.
 */
final class Assets {

    /**
     * Main init.
     *
     * @throws Exception Exception.
     */
    public static function init() {
        add_action( 'init', [ 'First_Party_Analytics\Assets\Assets', 'register_assets' ] );

        // Common public assets.

        add_action(
            'wp_enqueue_scripts',
            [ 'First_Party_Analytics\Assets\Publ\Publ', 'init' ]
        );

        add_action(
            'wp_enqueue_scripts',
            [ 'First_Party_Analytics\Assets\Publ\Public_Admin_Bar', 'init' ]
        );

        add_action(
            'current_screen',
            function () {
                $screen = get_current_screen();

                // Plugins assets screen.

                if ( 'plugins' === $screen->base ) {
                    new Menu\Screens\Plugins;
                }

                // Admin publish-box assets.

                if ( 'post' === $screen->base ) {
                    new Menu\Screens\Post;
                }

                // Dashboard assets.

                if ( 'dashboard' === $screen->id ) {
                    Dashboard::init();
                }
            }
        );

        // WC taxonomies assets.

        new Menu\Screens\WC_Taxonomies\Assets;
    }

    /**
     * Registers assets, that could be used later.
     */
    public static function register_assets() {
        self::register_script();
        self::register_styles();
    }

    /**
     * Registers scripts, that could be used later.
     */
    private static function register_script() {
        $dependencies = ( require FIRST_PARTY_ANALYTICS_DIR . 'assets/build/admin/post-and-admin-bar-vitals-table.asset.php' )['dependencies'];

        wp_register_script(
            'first-party-analytics-admin-post-and-admin-bar-vitals-table',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/post-and-admin-bar-vitals-table.js',
            $dependencies,
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );
    }

    /**
     * Registers styles, that could be used later.
     */
    private static function register_styles() {
        wp_register_style(
            'first-party-analytics-admin-post-and-admin-bar-vitals-table',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/post-and-admin-bar-vitals-table.css',
            [],
            FIRST_PARTY_ANALYTICS_VERSION
        );
    }
}
