<?php
/**
 * Assets for dashboard
 *
 * Loads assets (JS, CSS), adds data for them.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Assets;

/**
 * Assets class.
 */
final class Dashboard {

    /**
     * Inits.
     */
    public static function init() {
        $class = __CLASS__;
        add_action(
            'admin_enqueue_scripts',
            function () use ( $class ) {
                new $class();
            }
        );
    }

    /**
     * Constructor.
     */
    public function __construct() {
        $this->styles();
        $this->scripts();
    }

    /**
     * Loads styles.
     */
    private function styles() {
        wp_enqueue_style(
            'first-party-analytics-admin-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/index.css',
            [],
            FIRST_PARTY_ANALYTICS_VERSION
        );

        wp_enqueue_style(
            'first-party-analytics-admin-dashboard-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/dashboard.css',
            [],
            FIRST_PARTY_ANALYTICS_VERSION
        );
    }

    /**
     * Loads scripts.
     */
    private function scripts() {
        wp_register_script(
            'first-party-analytics-admin-script',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/index.js',
            [],
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );

        wp_enqueue_script(
            'first-party-analytics-admin-dashboard-script',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/dashboard.js',
            [ 'first-party-analytics-admin-script' ],
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );

        wp_localize_script(
            'first-party-analytics-admin-script',
            'firstPartyAnalytics',
            [
                'nonceToken' => wp_create_nonce( 'first-party-analytics-menu' ),
            ]
        );
    }
}
