<?php
/**
 * Assets for main screen
 *
 * Loads assets (JS, CSS), adds data for them.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Assets\Menu\Screens;

use First_Party_Analytics\Admin_Menu;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\Web_Vitals;
use First_Party_Analytics_Premium\Revisions\Revisions;

/**
 * Assets class.
 */
final class Main {

    /**
     * Cache key.
     */
    const CACHE_KEY = 'main-screen-data';

    /**
     * Inits.
     */
    public static function init() {
        $class = __CLASS__;
        add_action(
            'admin_enqueue_scripts',
            function () use ( $class ) {
                new $class();
            }
        );
    }

    /**
     * Constructor.
     */
    public function __construct() {
        $this->styles();
        $this->scripts();
    }

    /**
     * Loads styles.
     */
    private function styles() {
        wp_enqueue_style(
            'first-party-analytics-admin-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/index.css',
            [],
            FIRST_PARTY_ANALYTICS_VERSION
        );

        wp_enqueue_style(
            'first-party-analytics-admin-main-screen-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/main.css',
            [ 'first-party-analytics-admin-style', 'tmm-wp-plugins-core-admin-style' ],
            FIRST_PARTY_ANALYTICS_VERSION
        );
    }

    /**
     * Loads scripts.
     */
    private function scripts() {

        // Popper + Tippy.js.

        wp_register_script(
            'first-party-analytics-lib-popper',
            FIRST_PARTY_ANALYTICS_URL . 'libs/@popperjs/core/dist/umd/popper.min.js',
            [],
            '2.11.5',
            true
        );

        wp_register_script(
            'first-party-analytics-lib-tippyjs',
            FIRST_PARTY_ANALYTICS_URL . 'libs/tippy.js/dist/tippy-bundle.umd.min.js',
            [ 'first-party-analytics-lib-popper' ],
            '6.3.7',
            true
        );

        // Chart.js.

        wp_register_script(
            'first-party-analytics-lib-chart.js',
            FIRST_PARTY_ANALYTICS_URL . 'libs/chart.js/dist/chart.umd.min.js',
            [],
            '4.1.1',
            true
        );

        // Chart.js (data-labels plugin).

        wp_register_script(
            'first-party-analytics-lib-chart.js-plugin-datalabels',
            FIRST_PARTY_ANALYTICS_URL . 'libs/chartjs-plugin-datalabels/chartjs-plugin-datalabels.min.js',
            [ 'first-party-analytics-lib-chart.js' ],
            '2.0.0',
            true
        );

        // Chroma.js.

        wp_register_script(
            'first-party-analytics-lib-chroma.js',
            FIRST_PARTY_ANALYTICS_URL . 'libs/chroma.js/chroma.min.js',
            [],
            '2.4.0',
            true
        );

        // d3.

        wp_register_script(
            'first-party-analytics-lib-d3',
            FIRST_PARTY_ANALYTICS_URL . 'libs/d3/d3.min.js',
            [],
            '7.6.1',
            true
        );

        // d3-cloud (Word Cloud).

        wp_register_script(
            'first-party-analytics-lib-d3-cloud',
            FIRST_PARTY_ANALYTICS_URL . 'libs/d3-cloud/build/d3.layout.cloud.min.js',
            [ 'first-party-analytics-lib-d3' ],
            '1.2.5',
            true
        );

        // topojson.

        wp_register_script(
            'first-party-analytics-lib-topojson',
            FIRST_PARTY_ANALYTICS_URL . 'libs/topojson/dist/topojson.min.js',
            [],
            '3.0.2',
            true
        );

        // Admin common script.

        wp_register_script(
            'first-party-analytics-admin-script',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/index.js',
            [],
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );

        // Main script.

        $dependencies = ( require FIRST_PARTY_ANALYTICS_DIR . 'assets/build/admin/screens/main.asset.php' )['dependencies'];
        wp_enqueue_script(
            'first-party-analytics-admin-main-screen-script',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/main.js',
            array_merge(
                [
                    'tmm-wp-plugins-core-admin-script',
                    'first-party-analytics-admin-script',
                    'first-party-analytics-lib-chart.js',
                    'first-party-analytics-lib-chart.js-plugin-datalabels',
                    'first-party-analytics-lib-chroma.js',
                    'first-party-analytics-lib-d3-cloud',
                    'first-party-analytics-lib-topojson',
                    'first-party-analytics-lib-tippyjs',
                ],
                $dependencies
            ),
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );

        wp_localize_script(
            'first-party-analytics-admin-script',
            'firstPartyAnalytics',
            [
                'nonceToken'           => wp_create_nonce( 'first-party-analytics-menu' ),
                'txt'                  => Admin_Menu::get_texts(),
                'pluginBaseUrl'        => FIRST_PARTY_ANALYTICS_URL,
                'sourcesReservedNamed' => [
                    'Ads',
                    __( 'Direct visits', 'first-party-analytics' ),
                ],
                'i18n'                 => [
                    'dateFormat'  => get_option( 'date_format' ),
                    'timeFormat'  => get_option( 'time_format' ),
                    'startOfWeek' => get_option( 'start_of_week' ),
                ],
                'sources'              => First_Party_Analytics::$options->get( 'setting-sources' ),
                // Default revision.
                'revision'             => isset( $_GET['revision'] ) && 
                                        First_Party_Analytics::$premium_enabled &&
                                        (
                                            // Initial revision.
                                            0 === (int) wp_unslash( $_GET['revision'] ) || 
                                            // One of the published revisions.
                                            in_array( (int) wp_unslash( $_GET['revision'] ), array_keys( Revisions::get_revisions_list_with_ids() ), true ) 
                                        )
                    ? (int) wp_unslash( $_GET['revision'] ) : '', 
                'webVitalsThresholds'  => array_merge(
                    Web_Vitals::THRESHOLDS,
                    [
                        'WEB_VITALS_SCORE' => Web_Vitals::SCORE_THRESHOLD,
                    ]
                ),
                'msWebVitals'          => Web_Vitals::MS_METRICS,
                'secWebVitals'         => Web_Vitals::SEC_METRICS,
            ]
        );
    }
}
