<?php
/**
 * Assets for plugins screen
 *
 * Loads assets (JS, CSS), adds data for them.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Assets\Menu\Screens;

use Exception;

/**
 * Assets class.
 */
final class Plugins {

    /**
     * Inits.
     */
    public static function init() {
        $class = __CLASS__;
        add_action(
            'admin_enqueue_scripts',
            function () use ( $class ) {
                new $class();
            }
        );
    }

    /**
     * Constructor.
     *
     * @throws Exception Exception.
     */
    public function __construct() {
        $this->styles();
        $this->scripts();
    }

    /**
     * Loads styles.
     */
    private function styles() {
        wp_enqueue_style(
            'first-party-analytics-admin-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/index.css',
            [],
            FIRST_PARTY_ANALYTICS_VERSION
        );

        wp_enqueue_style(
            'first-party-analytics-admin-plugins-screen-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/plugins.css',
            [ 'first-party-analytics-admin-style', 'tmm-wp-plugins-core-admin-style' ],
            FIRST_PARTY_ANALYTICS_VERSION
        );
    }

    /**
     * Loads scripts.
     *
     * @throws Exception Exception.
     */
    private function scripts() {

        // Main script.

        wp_enqueue_script(
            'first-party-analytics-admin-plugins-screen-script',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/plugins.js',
            [ 'tmm-wp-plugins-core-admin-script' ],
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );

        wp_localize_script(
            'first-party-analytics-admin-plugins-screen-script',
            'firstPartyAnalytics',
            [
                'nonceToken' => wp_create_nonce( 'first-party-analytics-menu' ),
            ]
        );
    }
}
