<?php
/**
 * Assets for posts screen
 *
 * Loads assets (JS, CSS), adds data for them.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Assets\Menu\Screens;

use First_Party_Analytics\Databases\Page_Visits;
use First_Party_Analytics\Databases\Page_Visits_Finish;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\Utils;
use First_Party_Analytics\Web_Vitals;
use First_Party_Analytics\WooCommerce\Pages_Tracking_Data;
use First_Party_Analytics\WooCommerce\Products_Tracking_Data;

/**
 * Assets class.
 */
final class Post {

    /**
     * Constructor.
     */
    public function __construct() {
        if ( isset( $_GET['post'] ) ) { 
            $this->styles();
            $this->scripts();
        }
    }

    /**
     * Loads styles.
     */
    private function styles() {
        wp_enqueue_style(
            'first-party-analytics-admin-post-screen-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/post.css',
            [ 'tmm-wp-plugins-core-admin-style', 'first-party-analytics-admin-post-and-admin-bar-vitals-table' ],
            FIRST_PARTY_ANALYTICS_VERSION
        );
    }

    /**
     * Loads scripts.
     */
    private function scripts() {

        // Popper + Tippy.js.

        wp_register_script(
            'first-party-analytics-lib-popper',
            FIRST_PARTY_ANALYTICS_URL . 'libs/@popperjs/core/dist/umd/popper.min.js',
            [],
            '2.11.5',
            true
        );

        wp_register_script(
            'first-party-analytics-lib-tippyjs',
            FIRST_PARTY_ANALYTICS_URL . 'libs/tippy.js/dist/tippy-bundle.umd.min.js',
            [ 'first-party-analytics-lib-popper' ],
            '6.3.7',
            true
        );

        // Main script.

        $dependencies = ( require FIRST_PARTY_ANALYTICS_DIR . 'assets/build/admin/screens/post.asset.php' )['dependencies'];
        wp_enqueue_script(
            'first-party-analytics-admin-post-screen-script',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/post.js',
            array_merge(
                $dependencies,
                [
                    'tmm-wp-plugins-core-admin-script',
                    'first-party-analytics-lib-tippyjs',
                    'first-party-analytics-admin-post-and-admin-bar-vitals-table',
                ]
            ),
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );

        wp_set_script_translations(
            'first-party-analytics-admin-post-screen-script',
            'first-party-analytics',
            FIRST_PARTY_ANALYTICS_DIR . 'languages/js'
        );

        $current_post_id         = (int) $_GET['post']; 
        $post_type               = get_post_type( $current_post_id );
        $post_latest_revision_id = Utils::get_post_latest_revision_id( $current_post_id );

        $post_data = [
            'postType'               => $post_type,
            'visitsToday'            => Page_Visits::get_post_visits_count( $current_post_id, 7 ),
            'popularityRanking'      => Page_Visits::get_popularity_ranking( $current_post_id, 7 ),
            'bounceRate'             => Page_Visits::get_bounce_rate( $current_post_id, 7 ),
            'avgWebsiteDownloadSize' => Page_Visits_Finish::get_avg_website_data_download_size( $current_post_id, $post_latest_revision_id ),
            'avgAssetLessPageSize'   => Page_Visits_Finish::get_avg_asset_less_page_size( $current_post_id, $post_latest_revision_id ),
            'webVitalsTable'         => Web_Vitals::get_web_vitals_table( $current_post_id ),
        ];

        if ( First_Party_Analytics::$premium_enabled ) {
            $post_data = array_merge(
                $post_data,
                Pages_Tracking_Data::get_all( $current_post_id )
            );
        }

        if ( 'product' === $post_type ) {
            $post_data = array_merge(
                $post_data,
                Products_Tracking_Data::get_all( $current_post_id )
            );
        }

        wp_localize_script(
            'first-party-analytics-admin-post-screen-script',
            'firstPartyAnalytics',
            [
                'postData'       => $post_data,
                'pluginPage'     => admin_url( 'admin.php?page=first-party-analytics' ),
                'premiumEnabled' => First_Party_Analytics::$premium_enabled,
                'currency'       => Utils::get_currency(),
            ]
        );
    }
}
