<?php
/**
 * Assets for settings screen
 *
 * Loads assets (JS, CSS), adds data for them.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Assets\Menu\Screens;

use Exception;
use First_Party_Analytics\Admin_Menu;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\GeoLocation;
use First_Party_Analytics\No_Tracking_Cookie;

/**
 * Assets class.
 */
final class Settings {

    /**
     * Inits.
     */
    public static function init() {
        $class = __CLASS__;
        add_action(
            'admin_enqueue_scripts',
            function () use ( $class ) {
                new $class();
            }
        );
    }

    /**
     * Constructor.
     *
     * @throws Exception Exception.
     */
    public function __construct() {
        $this->styles();
        $this->scripts();
    }

    /**
     * Loads styles.
     */
    private function styles() {
        wp_register_style(
            'first-party-analytics-admin-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/index.css',
            [],
            FIRST_PARTY_ANALYTICS_VERSION
        );

        wp_enqueue_style(
            'first-party-analytics-admin-settings-screen-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/settings.css',
            [ 'first-party-analytics-admin-style', 'tmm-wp-plugins-core-admin-style' ],
            FIRST_PARTY_ANALYTICS_VERSION
        );
    }

    /**
     * Loads scripts.
     *
     * @throws Exception Exception.
     */
    private function scripts() {

        // Scripts.

        wp_register_script(
            'first-party-analytics-admin-script',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/index.js',
            [],
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );

        // Main script.

        wp_enqueue_script(
            'first-party-analytics-admin-settings-screen-script',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/settings.js',
            [ 'first-party-analytics-admin-script', 'tmm-wp-plugins-core-admin-script' ],
            FIRST_PARTY_ANALYTICS_VERSION,
            true
        );

        wp_localize_script(
            'first-party-analytics-admin-script',
            'firstPartyAnalytics',
            [
                'nonceToken'       => wp_create_nonce( 'first-party-analytics-menu' ),
                'txt'              => Admin_Menu::get_texts(),
                'cookies'          => First_Party_Analytics::$options->get( 'setting-exclusion-cookies' ),
                'ips'              => First_Party_Analytics::$options->get( 'setting-exclusion-ips' ),
                'myIP'             => GeoLocation::get_visitor_ip(),
                'noTrackingCookie' => [
                    'cookieName'        => No_Tracking_Cookie::COOKIE_NAME,
                    'foundHTML'         => No_Tracking_Cookie::get_found_html(),
                    'missingHTML'       => No_Tracking_Cookie::get_missing_html(),
                    'foundButtonHTML'   => No_Tracking_Cookie::get_found_button_html(),
                    'missingButtonHTML' => No_Tracking_Cookie::get_missing_button_html(),
                    'cookieExpiration'  => No_Tracking_Cookie::COOKIE_EXPIRATION,
                ],
            ]
        );
    }
}
