<?php
/**
 * Assets
 *
 * Main assets' handler.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Assets\Menu\Screens\WC_Taxonomies;

/**
 * Assets class.
 */
final class Assets {

    /**
     * Constructor.
     */
    public function __construct() {

        // Edit WC attributes.

        add_action(
            'current_screen',
            function () {
                $screen = get_current_screen();

                if (
                    'product_page_product_attributes' === $screen->id &&
                    ! isset( $_GET['edit'] ) 
                ) {
                    new Edit_Attributes();
                    $this->load_common_assets();
                }
            }
        );

        // Edit WC attribute terms.

        add_action(
            'current_screen',
            function () {
                $screen = get_current_screen();

                if (
                    str_starts_with( $screen->id, 'edit-pa_' ) &&
                    'edit-tags' === $screen->base &&
                    'product' === $screen->post_type
                ) {
                    new Edit_Attribute_Terms();
                    $this->load_common_assets();
                }
            }
        );

        // Edit WC categories.

        add_action(
            'current_screen',
            function () {
                $screen = get_current_screen();

                if ( 'edit-product_cat' === $screen->id ) {
                    new Edit_Categories();
                    $this->load_common_assets();
                }
            }
        );

        // Edit WC tags.

        add_action(
            'current_screen',
            function () {
                $screen = get_current_screen();

                if ( 'edit-product_tag' === $screen->id ) {
                    new Edit_Tags();
                    $this->load_common_assets();
                }
            }
        );
    }

    /**
     * Loads common assets.
     */
    public function load_common_assets() {
        $this->styles();
    }

    /**
     * Loads styles.
     */
    public function styles() {
        wp_enqueue_style(
            'first-party-analytics-admin-wc-taxonomies-style',
            FIRST_PARTY_ANALYTICS_URL . 'assets/build/admin/screens/wc-taxonomies/index.css',
            [],
            FIRST_PARTY_ANALYTICS_VERSION
        );
    }
}
