<?php
/**
 * Admin Menus
 *
 * Adds admin menus.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

/**
 * Class Admin_Menu.
 */
final class Admin_Menu {

    /**
     * Constructor.
     */
    public function __construct() {
        add_action( 'admin_menu', [ $this, 'init_menu' ], 9 ); // To show revisions post type below all other fields.
    }

    /**
     * Inits the menu.
     */
    public function init_menu() {
        $menu_slug = add_menu_page(
            __( 'First Party Analytics', 'first-party-analytics' ),
            __( 'First Party Analytics', 'first-party-analytics' ),
            'manage_options',
            'first-party-analytics',
            function () {
                require_once FIRST_PARTY_ANALYTICS_DIR . 'src/templates/admin/screens/main.php';
            },
            'dashicons-chart-area'
        );

        add_action(
            'load-' . $menu_slug,
            [ 'First_Party_Analytics\Assets\Menu\Screens\Main', 'init' ]
        );

        add_action(
            'load-' . $menu_slug,
            [ 'First_Party_Analytics\Get_Web_Vitals_Debug_Data', 'add_listeners' ]
        );

        $menu_slug = add_submenu_page(
            'first-party-analytics',
            __( 'First Party Analytics Settings', 'first-party-analytics' ),
            __( 'Settings', 'first-party-analytics' ),
            'manage_options',
            'first-party-analytics-settings',
            function () {
                require_once FIRST_PARTY_ANALYTICS_DIR . 'src/templates/admin/screens/settings.php';
            }
        );

        add_action(
            'load-' . $menu_slug,
            [ 'First_Party_Analytics\Settings_Export', 'add_listeners' ]
        );

        add_action(
            'load-' . $menu_slug,
            [ 'First_Party_Analytics\Assets\Menu\Screens\Settings', 'init' ]
        );
    }

    /**
     * Returns an array of texts for the admin scripts.
     */
    public static function get_texts() {
        return [
            'error'                            => __( 'Error', 'first-party-analytics' ),
            'somethingWentWrong'               => __( 'Something went wrong.', 'first-party-analytics' ),
            'yes'                              => __( 'Yes', 'first-party-analytics' ),
            'no'                               => __( 'No', 'first-party-analytics' ),
            'resetAllSettingsNotice'           => __( 'Are you sure you want to reset all plugin settings?', 'first-party-analytics' ),
            'yesResetAllSettings'              => __( 'Yes, reset all plugin settings!', 'first-party-analytics' ),
            /* translators: %s is a plugin name. */
            'settingsAreImporting'             => sprintf( __( '%s settings are importing.', 'first-party-analytics' ), First_Party_Analytics::$name ),
            'pleaseWait'                       => __( 'Please wait.', 'first-party-analytics' ),
            'searches'                         => __( 'Searches:', 'first-party-analytics' ),
            /* translators: %d is the number of visits. */
            'n_visits'                         => __( '%d visits', 'first-party-analytics' ),
            'numberOfViews'                    => __( '# of Views', 'first-party-analytics' ),
            'cookieInjectionNoticeHeader'      => __( 'No-tracking cookie was injected into your browser.', 'first-party-analytics' ),
            'cookiesInjectionNoticeContent'    => __( 'It will <b>not</b> work when you are in incognito or using a different browser.', 'first-party-analytics' ),
            'thankYou'                         => __( 'Thank you', 'first-party-analytics' ),
            'noTrackCookieRemovalNoticeHeader' => __( 'No-track cookie was removed from your browser.', 'first-party-analytics' ),
            'other'                            => __( 'Other', 'first-party-analytics' ),
            'clickOnSliceToExpand'             => __( 'Click on slice to expand', 'first-party-analytics' ),
            'productViews'                     => __( 'Product views', 'first-party-analytics' ),
            'example'                          => __( 'Example:', 'first-party-analytics' ),
            'sourceInsertDomainNamePopupText'  => __( 'Domain name has to be either like <b>news.google.com</b> or like <b>news.google.*</b><br>(for news.google.{com|co.uk|nl|etc}).', 'first-party-analytics' ),
            'enterTheNameOfSource'             => __( 'Enter the name of source', 'first-party-analytics' ),
            'enterTheReferrerOfSource'         => __( 'Enter the referrer of source', 'first-party-analytics' ),
            /* translators: %s is the current name. */
            'enterGroupName'                   => __( 'Enter the new group name to add to "%s"', 'first-party-analytics' ),
            'enterName'                        => __( 'Enter name', 'first-party-analytics' ),
            /* translators: %s is the current name. */
            'enterNewName'                     => __( 'Enter new name for "%s"', 'first-party-analytics' ),
            'enterReferrer'                    => __( 'Enter referrer', 'first-party-analytics' ),
            'pleaseEnterTheValue'              => __( 'Please enter the value', 'first-party-analytics' ),
            'cancel'                           => __( 'Cancel', 'first-party-analytics' ),
            'areYouSure'                       => __( 'Are you sure?', 'first-party-analytics' ),
            /* translators: %s is the current name. */
            'sourceGroupDeleteNotice'          => __( 'The selected source group (<b>"%s"</b>), all its subgroups and all their rules will be deleted forever.', 'first-party-analytics' ),
            'next'                             => __( 'Next', 'first-party-analytics' ),
            'save'                             => __( 'Save', 'first-party-analytics' ),
            'sourcesResetNotice'               => __( 'All sources will be reset to default.', 'first-party-analytics' ),
            'youCanBackupYourSettingsNote'     => __( 'Note: You can <b>backup</b> your settings before doing this.', 'first-party-analytics' ),
            'itWillBeDeletedForever'           => __( 'It will be deleted forever.', 'first-party-analytics' ),
            'youCantUseSlash'                  => __( 'You can\'t use "/"', 'first-party-analytics' ),
            'youCantOnlyDigitsForTheName'      => __( 'You can\'t use only digits for the name', 'first-party-analytics' ),
            'youAlreadyHaveGroupWithThisName'  => __( 'You already have source group with this name', 'first-party-analytics' ),
            'thisNameIsReversed'               => __( 'This name is reversed. Use another one.', 'first-party-analytics' ),
            'pleaseEnterAValidDomainName'      => __( 'Please enter a valid domain name.', 'first-party-analytics' ),
        ];
    }
}
