<?php
/**
 * A class for average math - incremental averaging, for example.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

/**
 * Class Average_Math.
 */
final class Average_Math {

    /**
     * Percentile.
     *
     * @var int|float
     */
    const PERCENTILE = 90;

    /**
     * Returns percentile value for the array.
     *
     * @param array     $array      Array.
     * @param int|float $percentile Percentile.
     *
     * @return int|float Array percentile value.
     */
    public static function get_percentile( $array, $percentile = self::PERCENTILE ) {
        sort( $array );
        $index = ( $percentile / 100 ) * count( $array );
        if ( floor( $index ) === $index ) {
            $result = ( $array[ $index - 1 ] + $array[ $index ] ) / 2;
        } else {
            $result = $array[ floor( $index ) ];
        }
        return $result;
    }

    /**
     * Filters out the array by percentile.
     *
     * @param array     $array      Array.
     * @param int|float $percentile Percentile.
     *
     * @return array The array filtered out by percentile.
     */
    public static function filter_out_by_percentile( $array, $percentile = self::PERCENTILE ) {
        $percentile = self::get_percentile( $array, $percentile );

        return array_filter(
            $array,
            function( $x ) use ( $percentile ) {
                return $x < $percentile;
            }
        );
    }

    /**
     * Returns array average.
     *
     * @param int|float[] $array Array of integers.
     *
     * @return float|int Array average value.
     */
    public static function get_array_average( $array ) {
        return array_sum( $array ) / count( $array );
    }
}
