<?php
/**
 * A class with methods for countries.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

/**
 * Class Countries.
 */
final class Countries {

    /**
     * Returns countries ISO codes.
     *
     * Possible values (for $key or $value):
     *
     * [name] => Yemen
     * [alpha-2] => YE
     * [country-code] => 887
     *
     * @param string $key   An array key.
     * @param string $value An array value.
     *
     * @return array Countries ISO codes.
     */
    public static function get_countries_iso_data( $key = 'country-code', $value = 'alpha-2' ) {
        static $countries;
        if ( null === $countries ) { // Cache.
            $countries = json_decode(
                First_Party_Analytics::$fs->get_contents( FIRST_PARTY_ANALYTICS_DIR . 'libs/ISO-3166-Countries-with-Regional-Codes-9.0/slim-2/slim-2.json' ),
                true
            );
        }

        return array_column( $countries, $value, $key );
    }

    /**
     * Converts country ISO-code to name.
     *
     * @param string $iso_code ISO code of the country.
     *
     * @return string Name of the country.
     */
    public static function convert_country_iso_code_to_name( $iso_code ) {
        if ( ! $iso_code ) {
            return __( 'Unknown', 'first-party-analytics' );
        }

        return self::get_countries_iso_data( 'alpha-2', 'name' )[ $iso_code ];
    }
}
