<?php
/**
 * A class for data removal helper methods.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

use First_Party_Analytics\Databases\Page_Visits_Finish;
use First_Party_Analytics\WooCommerce\Pages_Tracking_Data;
use First_Party_Analytics\WooCommerce\Products_Tracking_Data;

/**
 * A class for data removal methods.
 */
final class Data_Removal_Helpers {

    /**
     * "Like" meta keys.
     *
     * Vales should be numeric.
     */
    const LIKE_META_KEYS = [
        Products_Tracking_Data::TIMES_PURCHASED_META_KEY,
        Products_Tracking_Data::ADDED_TO_CART_TRACKER_META_KEY,
        Products_Tracking_Data::VIEWED_IN_CATALOG_COUNT_TRACKER_META_KEY,
        Pages_Tracking_Data::CONVERSION_DEPTH_META_KEY,
        Pages_Tracking_Data::CONVERSIONS_VALUE_META_KEY,
        Page_Visits_Finish::REQUESTS_ENQUEUE_POST_META_NAME,
    ];

    /**
     * Get like meta keys.
     *
     * @param int|string $suffix Suffix for data removal (revision ID, for example); if not set then the match will be more broad.
     *
     * @return string[] Like meta-keys.
     */
    public static function get_like_meta_keys( $suffix = '' ) {
        return array_map(
            function( $v ) use ( $suffix ) {
                // Add revision to all meta-keys.
                return $v . $suffix;
            },
            self::LIKE_META_KEYS
        );
    }

    /**
     * Delete "like" meta fields from posts.  With optional suffix (revision ID, for example).
     *
     * @param int|string $suffix Suffix for data removal (revision ID, for example); if not set then the match will be more broad.
     */
    public static function delete_like_meta_keys( $suffix = '' ) {
        foreach ( self::get_like_meta_keys( $suffix ) as $like_meta_key ) {
            $pages = get_posts(
                [
                    'post_type'      => 'any',
                    'post_status'    => 'any',
                    'posts_per_page' => -1,
                    'meta_query'     => [
                        [
                            'key'         => $like_meta_key,
                            'compare_key' => 'LIKE',
                        ],
                    ],
                    'fields'         => 'ids',
                ]
            );

            foreach ( $pages as $page_id ) {
                $keys_to_delete = array_filter(
                    array_keys( get_post_meta( $page_id ) ),
                    function( $meta_key ) use ( $like_meta_key ) {
                        return str_starts_with( $meta_key, $like_meta_key );
                    }
                );

                foreach ( $keys_to_delete as $meta_key ) {
                    delete_post_meta( $page_id, $meta_key );
                }
            }
        }
    }
}
