<?php
/**
 * A class responsible for MU-plugin setup and update.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

/**
 * Class Mu_Plugin.
 */
final class Mu_Plugin {

    /**
     * MU plugin name.
     */
    const MU_PLUGIN_NAME = 'first-party-analytics-ajax-optimizer.php';

    /**
     * Path to the MU plugin dir.
     */
    const PATH_IN_PLUGIN = FIRST_PARTY_ANALYTICS_DIR . 'src/mu-plugin/' . self::MU_PLUGIN_NAME;

    /**
     * SpeedSearch MU plugin path in MU plugins dir.
     */
    const PATH_IN_MU_DIR = WPMU_PLUGIN_DIR . '/' . self::MU_PLUGIN_NAME;

    /**
     * Constructor.
     */
    public function __construct() {
        // Adds MU plugin on plugin activation.
        register_activation_hook( FIRST_PARTY_ANALYTICS_FILE, [ $this, 'copy_mu_plugin' ] );

        // Removes MU plugin on plugin deactivation.
        register_deactivation_hook( FIRST_PARTY_ANALYTICS_FILE, [ $this, 'delete_mu_plugin' ] );

        if ( ! self::is_mu_plugin_installed() || self::is_installed_mu_plugin_outdated() ) {
            $this->copy_mu_plugin();
        }
    }

    /**
     * Checks whether the MU plugin is installed.
     *
     * @return bool
     */
    public function is_mu_plugin_installed() {
        return First_Party_Analytics::$fs->is_file( self::PATH_IN_MU_DIR );
    }

    /**
     * Checks whether the currently installed MU installed plugin version is outdated.
     *
     * @return bool
     */
    public function is_installed_mu_plugin_outdated() {
        return get_file_data( self::PATH_IN_PLUGIN, [ 'Version' ] )[0] !== get_file_data( self::PATH_IN_MU_DIR, [ 'Version' ] )[0]; 
    }

    /**
     * Plugin activation handler.
     *
     * Adds MU plugin on plugin activation.
     */
    public function copy_mu_plugin() {
        if ( ! First_Party_Analytics::$fs->is_dir( WPMU_PLUGIN_DIR ) ) {
            First_Party_Analytics::$fs->mkdir( WPMU_PLUGIN_DIR, 0755, true );
        }
        First_Party_Analytics::$fs->delete( self::PATH_IN_MU_DIR );
        First_Party_Analytics::$fs->copy( self::PATH_IN_PLUGIN, self::PATH_IN_MU_DIR );
    }

    /**
     * Plugin deactivation handler.
     *
     * Removes MU plugin on plugin deactivation.
     */
    public function delete_mu_plugin() {
        if ( First_Party_Analytics::$fs->is_file( self::PATH_IN_MU_DIR ) ) {
            First_Party_Analytics::$fs->delete( self::PATH_IN_MU_DIR );
        }
    }
}
