<?php
/**
 * A class for handling the no-tracking cookie.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

/**
 * Class No_Tracking_Cookie.
 */
final class No_Tracking_Cookie {

    /**
     * No-tracking cookie name.
     */
    const COOKIE_NAME = 'first_party_analytics_do_not_track';    /**

    /**
     * Do not track cookie expiration, in seconds.
     */
    const COOKIE_EXPIRATION = YEAR_IN_SECONDS * 10;

    /**
     * Returns no-tracking cookie status.
     *
     * @return bool True for found, false for not found.
     */
    public static function is_found() {
        return isset( $_COOKIE[ self::COOKIE_NAME ] );
    }

    /**
     * Returns HTML for the relevant no-tracking cookie value.
     *
     * @return string HTML.
     */
    public static function get_current_status_html() {
        return self::is_found() ? self::get_found_html() : self::get_missing_html();
    }

    /**
     * Returns no-tracking cookie found HTML.
     *
     * @return string HTML.
     */
    public static function get_found_html() {
        return '<span class="first-party-analytics-text-green">' . esc_html__( 'Found', 'first-party-analytics' ) . '</span>';
    }

    /**
     * Returns no-tracking cookie missing HTML.
     *
     * @return string HTML.
     */
    public static function get_missing_html() {
        return '<span class="first-party-analytics-text-orange">' . esc_html__( 'Missing', 'first-party-analytics' ) . '</span>';
    }

    /**
     * Returns no-tracking cookie found button HTML.
     *
     * @return string HTML.
     */
    public static function get_found_button_html() {
        return get_submit_button(
            __(
                'Delete no-tracking cookie from my browser',
                'first-party-analytics'
            ),
            [
                'secondary',
                'first-party-analytics-delete-no-tracking-cookie',
                'ml-0',
            ]
        );
    }

    /**
     * Returns no-tracking cookie missing button HTML.
     *
     * @return string HTML.
     */
    public static function get_missing_button_html() {
        return get_submit_button(
            __(
                'Inject no-tracking cookie into my browser',
                'first-party-analytics'
            ),
            [
                'secondary',
                'first-party-analytics-inject-no-tracking-cookie',
                'ml-0',
            ]
        );
    }

    /**
     * Returns current status button HTML.
     *
     * @return string HTML.
     */
    public static function get_current_status_button_html() {
        return self::is_found() ? self::get_found_button_html() : self::get_missing_button_html();
    }
}
