<?php
/**
 * A class that adds ping attribute to the links.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

/**
 * Class Ping_Attribute_To_Links.
 */
final class Ping_Attribute_To_Links {

    /**
     * Constructor.
     */
    public function __construct() {
        if (
            First_Party_Analytics::$options->get( 'setting-add-ping-attribute' ) &&
            isset( $_SERVER['REQUEST_METHOD'] ) &&
            'GET' === sanitize_text_field( wp_unslash( $_SERVER['REQUEST_METHOD'] ) ) &&
            ! is_admin() &&
            ! wp_doing_cron() &&
            ! wp_doing_ajax() &&
            isset( $_SERVER['HTTP_ACCEPT'] ) &&
            '*/*' !== sanitize_text_field( wp_unslash( $_SERVER['HTTP_ACCEPT'] ) ) // When the request goes from the browser (e.g. fetch() method for GET() (this is how saffy works)).
        ) {
            $this->init();
        }
    }

    /**
     * Adds filters.
     */
    private function init() {
        ob_start();
        add_action( 'shutdown', [ $this, 'handle_final_output' ], 0 );
    }

    /**
     * Handles final output.
     */
    public function handle_final_output() {
        $final_output = '';

        // We'll need to get the number of ob levels we're in, so that we can iterate over each, collecting
        // that buffer's output into the final output.
        $levels = ob_get_level();

        for ( $i = 0; $i < $levels; $i++ ) {
            $final_output .= ob_get_clean();
        }

        $this->post_process_final_output( $final_output );
    }

    /**
     * Post-processes the final output.
     *
     * Adds "ping" attribute to all "a" tags; and then echoes it.
     *
     * @param string $final_output Final output.
     */
    private function post_process_final_output( $final_output ) {
        $post_id = Utils::get_currently_requested_post_id();

        $ping_url = "/?plugin=first-party-analytics&action=link_ping&post_id=$post_id";

        echo preg_replace_callback( 
            '@(<a)(\s)(ping=[\'"](.*?)[\'"])?([^>]*)@',
            function( $matches ) use ( $ping_url ) {
                if ( ! str_contains( $matches[0], 'ping=' ) ) {
                    return $matches[1] . " ping=\"$ping_url\" " . $matches[3] . $matches[4] . $matches[5];
                } else {
                    return $matches[1] . $matches[2] . "ping=\"$ping_url" . ( $matches[4] ? " $matches[4]" : '' ) . '"' . $matches[5];
                }
            },
            $final_output
        );
    }
}
