<?php
/**
 * A class for the storage of the raw requests.
 *
 * Usually used to store the last 1k of requests in the option (DB) to calculate percentiles.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

use First_Party_Analytics_Premium\First_Party_Analytics_Premium;

/**
 * Class Raw_Requests_Storage.
 */
final class Raw_Requests_Storage {

    /**
     * How many requests of each type to store.
     *
     * @var int
     */
    const REQUESTS_OF_TYPE_TO_STORE = 1000;

    /**
     * Writes the raw requests sequence for fieldset.
     *
     * @param string  $fieldset_name Fieldset name. AKA request type name. AKA file name.
     * @param array   $lines         Lines to write.
     * @param boolean $for_premium   For premium plugin.
     */
    public static function write_for_fieldset( $fieldset_name, array $lines, $for_premium = false ) {
        $raw_requests = ! $for_premium ?
            First_Party_Analytics::$options->get( 'raw-requests' ) :
            First_Party_Analytics_Premium::$options->get( 'raw-requests' );

        $raw_requests[ $fieldset_name ] = array_merge( isset( $raw_requests[ $fieldset_name ] ) ? $raw_requests[ $fieldset_name ] : [], $lines );
        $count                          = count( $raw_requests[ $fieldset_name ] );

        if ( $count > self::REQUESTS_OF_TYPE_TO_STORE ) {
            $requests_to_remove             = $count - self::REQUESTS_OF_TYPE_TO_STORE;
            $raw_requests[ $fieldset_name ] = array_slice( $raw_requests[ $fieldset_name ], $requests_to_remove );
        }

        ! $for_premium ?
            First_Party_Analytics::$options->set( 'raw-requests', $raw_requests ) :
            First_Party_Analytics_Premium::$options->set( 'raw-requests', $raw_requests );
    }

    /**
     * Retrieves the raw requests sequence for fieldset.
     *
     * @param string  $fieldset_name Fieldset name. AKA request type name. AKA file name.
     * @param boolean $for_premium   For premium plugin.
     *
     * @return array
     */
    public static function get_for_fieldset( $fieldset_name, $for_premium = false ) {
        $raw_requests = ! $for_premium ?
            First_Party_Analytics::$options->get( 'raw-requests' ) :
            First_Party_Analytics_Premium::$options->get( 'raw-requests' );

        return isset( $raw_requests[ $fieldset_name ] ) ? $raw_requests[ $fieldset_name ] : [];
    }
}
