<?php
/**
 * Removes visitors for the previous day for visitors DB table.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

use Exception;

/**
 * Class Raw_Analytics_Data_Parsing.
 */
final class Remove_Visitors_For_The_Previous_Day {

    /**
     * Interval hook name.
     */
    const INTERVAL_HOOK_NAME = 'first_party_analytics_remove_visitors_for_the_previous_day';

    /**
     * Interval.
     */
    const INTERVAL = HOUR_IN_SECONDS * 12;

    /**
     * Constructor.
     */
    public function __construct() {
        // Schedule the action.
        add_action( 'init', [ $this, 'schedule_interval' ] );

        // Unschedule interval action on plugin deactivation.
        register_deactivation_hook( FIRST_PARTY_ANALYTICS_FILE, [ $this, 'plugin_deactivation_handler' ] );

        // Process action.
        add_action( self::INTERVAL_HOOK_NAME, [ 'First_Party_Analytics\Databases\Visitors', 'remove_visitors_for_the_previous_day' ] );
    }

    /**
     * Schedules the interval action if it isn't scheduled.
     *
     * @throws Exception Exception.
     */
    public static function schedule_interval() {
        if ( ! as_next_scheduled_action( self::INTERVAL_HOOK_NAME ) ) {
            as_schedule_recurring_action(
                time(),
                self::INTERVAL,
                self::INTERVAL_HOOK_NAME
            );
        }
    }

    /**
     * Plugin deactivation handler.
     */
    public function plugin_deactivation_handler() {
        as_unschedule_all_actions( self::INTERVAL_HOOK_NAME );
    }
}
