<?php
/**
 * A class for revision-specific tracking data handling.
 *
 * @package First-Party-Analytics-Premium
 */

namespace First_Party_Analytics_Premium;

use First_Party_Analytics\First_Party_Analytics;

/**
 * Class Revision_Specific_Data.
 */
final class Revision_Specific_Data {

    /**
     * Add post tracking meta key.
     *
     * @param int    $post_id   Post ID.
     * @param string $meta_key  Tracking meta key.
     * @param int    $quantity  Quantity to increment.
     */
    public static function post_meta_increment_counter( $post_id, $meta_key, $quantity = 1 ) {

        // Add to global counter.

        $counter     = (int) get_post_meta( $post_id, $meta_key, true );
        $new_counter = $counter + $quantity;
        update_post_meta( $post_id, $meta_key, $new_counter );

        // Add to revision-specific counter.

        if ( First_Party_Analytics::$premium_enabled ) {
            $current_revision_id = \First_Party_Analytics_Premium\Revisions\Revisions::get_current_revision_id();

            if ( $current_revision_id ) {
                $meta_key_with_revision = $meta_key . $current_revision_id;

                $counter     = (int) get_post_meta( $post_id, $meta_key_with_revision, true );
                $new_counter = $counter + $quantity;
                update_post_meta( $post_id, $meta_key_with_revision, $new_counter );
            }
        }
    }

    /**
     * Get main, and revision dependent key, if available.
     *
     * @param string $key Key that will be returned, with a revision key, potentially.
     *
     * @return array One, or two of keys (if revision is specified).
     */
    public static function get_passed_and_revision_specific_key( $key ) {
        $keys = [ $key ];

        // Add the revision-specific key.

        if ( First_Party_Analytics::$premium_enabled ) {
            $current_revision_id = \First_Party_Analytics_Premium\Revisions\Revisions::get_current_revision_id();
            if ( $current_revision_id ) {
                $keys[] = $key . $current_revision_id;
            }
        }

        return $keys;
    }
}
