<?php
/**
 * A class for stop-words.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

use Exception;

/**
 * Class Stop_Words.
 */
final class Stop_Words {

    /**
     * Get the list of stop words.
     *
     * @param bool|string $language The language to get stop-words for. If not specified, returns all languages.
     *
     * @return array
     */
    private static function get_stop_words( $language = false ) {
        static $content;
        if ( null === $content ) { // Cache.
            $content = json_decode(
                First_Party_Analytics::$fs->get_contents(
                    FIRST_PARTY_ANALYTICS_DIR . 'libs/stop-words/stop-words.json'
                ),
                true
            );
        }

        if ( ! $language ) {
            return $content;
        } elseif ( isset( $content[ strtolower( $language ) ] ) ) {
            return $content[ strtolower( $language ) ];
        } else {
            return [];
        }
    }

    /**
     * Get the list of stop words for site languages.
     *
     * @return array
     */
    public static function get_stop_words_for_site_languages() {
        $languages = wp_get_installed_translations( 'core' );

        static $stop_words_list = [];
        if ( $stop_words_list ) { // Cache.
            return $stop_words_list;
        }

        $locales_list = [ 'en_US' ];
        if ( $languages['default'] ) {
            foreach ( $languages['default'] as $language => $meta ) {
                $locales_list[] = $language;
            }
        }

        $languages_list = array_map(
            function( $locale ) {
                return explode( '_', $locale )[0];
            },
            $locales_list
        );

        foreach ( $languages_list as $language ) {
            $stop_words_list = array_merge( $stop_words_list, self::get_stop_words( $language ) );
        }

        return $stop_words_list;
    }
}
