<?php
/**
 * A class for tabs data.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

use First_Party_Analytics\Databases\Search_Words;
use First_Party_Analytics\Databases\Visitor_Details;
use First_Party_Analytics\Representation\Graphs\Average_Load_Time;
use First_Party_Analytics\Representation\Graphs\Average_Page_Views_Per_Session;
use First_Party_Analytics\Representation\Graphs\Average_Session_Duration;
use First_Party_Analytics\Representation\Graphs\Average_View_Time;
use First_Party_Analytics\Representation\Graphs\Bounce_Rate;
use First_Party_Analytics\Representation\Graphs\General_Views;
use First_Party_Analytics\Representation\Graphs\Hour_Views;
use First_Party_Analytics\Representation\Graphs\Number_Of_Sessions;
use First_Party_Analytics\Representation\Graphs\Returning_Visitors;
use First_Party_Analytics\Representation\Graphs\Weekday_Views;

/**
 * Class Tabs_Data.
 */
final class Tabs_Data {

    /**
     * Get general tab data.
     */
    public static function get_general_tab_data() {
        return [
            'stats'               => false === General_Views::get_all_views() ? false : General_Views::get_data(),
            'weekdayViews'        => Weekday_Views::get_data(),
            'hourViews'           => Hour_Views::get_data(),
            'charts'              => [
                'js-enabled'        => Visitor_Details::get_data( 'noscript', true, true, true ),
                'dnt'               => Visitor_Details::get_data( 'dnt', true, true ),
                'adblock'           => Visitor_Details::get_data( 'adblockActive', true, true ),
                'analytics-blocked' => Visitor_Details::get_data( 'analyticsBlocked', true, true ),
                'os'                => Visitor_Details::get_data( 'os' ),
                'device'            => Visitor_Details::get_data( 'device' ),
                'browser'           => Visitor_Details::get_data( 'browser' ),
            ],
            'bounceRateChartData' => false === Bounce_Rate::get_all_time() ? false : Bounce_Rate::get_data(),
            'returningVisitors'   => false === Returning_Visitors::get_all_time() ? false : Returning_Visitors::get_data(),
            'browserFull'         => Visitor_Details::get_data( 'browserFull', false ),
        ];
    }

    /**
     * Get times tab data.
     */
    public static function get_times_tab_data() {
        return [
            'avgViewTimeChartData' => false === Average_View_Time::get_all_time() ? false : Average_View_Time::get_data(),
        ];
    }

    /**
     * Get interaction capabilities tab data.
     */
    public static function get_interaction_capabilities_tab_data() {
        return [
            'charts'           => [
                'pointer-type'  => Visitor_Details::get_data( 'pointerType' ),
                'touch-support' => Visitor_Details::get_data( 'hasTouch', true, true ),
                'touch-only'    => Visitor_Details::get_data( 'isDeviceTouchOnly', true, true ),
            ],
            'horizontalCharts' => [
                'interaction-capabilities' => Visitor_Details::get_data( 'interactionCapabilities' ),
            ],
        ];
    }

    /**
     * Get sessions tab data.
     */
    public static function get_sessions_tab_data() {
        return [
            'averageSessionDuration'     => false === Average_Session_Duration::get_all_time() ? false : Average_Session_Duration::get_data(),
            'averagePageViewsPerSession' => false === Average_Page_Views_Per_Session::get_all_time() ? false : Average_Page_Views_Per_Session::get_data(),
            'numberOfSessions'           => false === Number_Of_Sessions::get_all_time() ? false : Number_Of_Sessions::get_data(),
        ];
    }

    /**
     * Get screen sizes tab data.
     */
    public static function get_screen_sizes_tab_data() {
        return [
            'horizontalCharts' => [
                'screen-resolution'          => Visitor_Details::get_data( 'screen-resolution' ),
                'breakpoint-and-orientation' => Visitor_Details::get_data( 'breakpointAndOrientation' ),
            ],
        ];
    }

    /**
     * Get languages tab data.
     */
    public static function get_languages_tab_data() {
        return [
            'horizontalCharts' => [
                'language'           => Visitor_Details::get_data( 'language' ),
                'supported-language' => Visitor_Details::get_data( 'supportedLanguage' ),
            ],
        ];
    }

    /**
     * Get countries tab data.
     */
    public static function get_countries_tab_data() {
        return [
            'countriesTopology' => First_Party_Analytics::$fs->get_contents( FIRST_PARTY_ANALYTICS_DIR . 'libs/world-atlas/countries-110m.json' ),
            'countriesISOCodes' => Countries::get_countries_iso_data(),
            'countriesVisits'   => Visitor_Details::get_data( 'country', false ),
        ];
    }

    /**
     * Get search tab data.
     */
    public static function get_search_tab_data() {
        return [
            'searchWords' => Search_Words::get_for_word_cloud(),
        ];
    }

    /**
     * Get Performance tab data.
     */
    public static function get_performance_tab_data() {
        return [
            'avgLoadTimeChartData' => false === Average_Load_Time::get_all_time() ? false : Average_Load_Time::get_data(),
        ];
    }

    /**
     * Get Misc tab data.
     */
    public static function get_misc_tab_data() {
        return [
            'horizontalCharts' => [
                'connection-protocol' => Visitor_Details::get_data( 'connectionProtocol' ),
            ],
        ];
    }
}
