<?php
/**
 * A class to handle tracking cookies.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics;

/**
 * Class Server_Side_Analytics.
 */
final class Tracking_Cookies {

    /**
     * The name of the cookie.
     */
    const COOKIE_NAME = 'first_party_analytics_uid';

    /**
     * Identifier cookies length.
     */
    const COOKIE_LENGTH = 20;

    /**
     * Identifier cookies expiration, in seconds.
     */
    const COOKIE_EXPIRATION = YEAR_IN_SECONDS;

    /**
     * Generates cookie value.
     *
     * @return string Cookie value.
     */
    public static function generate_cookie_value() {
        $output = wp_rand( 1, 9 );

        for ( $i = 1; $i < self::COOKIE_LENGTH; $i++ ) {
            $output .= wp_rand( 0, 9 );
        }

        return $output;
    }

    /**
     * Returns the visitor tracking cookie value.
     *
     * If no cookie, then this request is considered "detached" and attached to user ID automatically by search of the next request for the same IP and URL.
     *
     * Only the first server-side request is expected to be detached, because we set tracking cookie either with JS script or NoScript image.
     *
     * @return string Cookie value or empty string if cookie is not set.
     */
    public static function get_cookie() {
        if ( isset( $_COOKIE[ self::COOKIE_NAME ] ) ) {
            return sanitize_text_field( wp_unslash( $_COOKIE[ self::COOKIE_NAME ] ) );
        } else {
            return '';
        }
    }
}
