<?php
/**
 * A class for Link_Visits database table management.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Databases;

/**
 * Class Link_Visits.
 */
final class Link_Visits extends Database {

    /**
     * Table name.
     */
    const NAME = 'link_visits';

    /**
     * Writes to the DB.
     *
     * @param string $visitor_id   Visitor ID.
     * @param int    $post_id      ID of the post.
     * @param string $time         Time of the visit.
     * @param string $source       The page URL from which the visit occurred.
     * @param string $href         The href of the visited URL.
     * @param string $href_host    Hostname of the visited link.
     * @param string $href_main_domain Domain of the visited link.
     * @param string $url_params   URL params.
     * @param bool   $external_dst External link visit destination.
     * @param int    $revision_id  Revision ID.
     */
    public static function write( $visitor_id, $post_id, $time, $source, $href, $href_host, $href_main_domain, $url_params, $external_dst, $revision_id ) {
        global $wpdb;

        $table_name = self::get_table_name();

        $query = $wpdb->prepare( 
            "
            INSERT INTO $table_name (visitor_id, `post_id`, `time`, `source`, `href`, `href_host`, `href_main_domain`, `href_url_params`, `external_dst`, revision_id)
            VALUES (%s, %d, %s, %s, %s, %s, %s, %s, %d, %d);
        ",
            $visitor_id,
            $post_id,
            $time,
            $source,
            $href,
            $href_host,
            $href_main_domain,
            $url_params,
            (int) $external_dst,
            $revision_id
        );

        $wpdb->query( $query ); 
    }
}
