<?php
/**
 * A class for Time_Of_Day database table management.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Databases;

/**
 * Class Time_Of_Day.
 */
final class Time_Of_Day extends Database {

    /**
     * Table name.
     */
    const NAME = 'time_of_day';

    /**
     * Converts requests sequence into DB population.
     *
     * @param array $requests_sequence Requests sequence.
     */
    public static function convert_sequence_into_db_population( $requests_sequence ) {
        foreach ( $requests_sequence as $request ) {
            $day_of_week = gmdate( 'w', strtotime( $request['time'] ) );

            $hour_of_day    = gmdate( 'G', strtotime( $request['time'] ) );
            $minute_of_hour = gmdate( 'i', strtotime( $request['time'] ) );
            $minute_of_day  = $hour_of_day * 60 + $minute_of_hour;
            $revision_id    = (int) $request['revisionId'];

            self::write( $day_of_week, $minute_of_day, $revision_id );
        }
    }

    /**
     * Writes to the DB.
     *
     * @param string $day_of_week   Day of week.
     * @param string $minute_of_day Minute of day.
     * @param int    $revision_id   Revision ID.
     */
    public static function write( $day_of_week, $minute_of_day, $revision_id ) {
        global $wpdb;

        $table_name = self::get_table_name();

        $query = $wpdb->prepare( 
            "
            INSERT INTO $table_name (day_of_week, minute_of_day, visits_count, revision_id) VALUES (%d, %d, 1, %d) ON DUPLICATE KEY UPDATE

            visits_count = visits_count + 1;
        ",
            $day_of_week,
            $minute_of_day,
            $revision_id
        );

        $wpdb->query( $query ); 
    }
}
