<?php
/**
 * A class with Debug methods for DB population.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Debug;

use First_Party_Analytics\Databases\Page_Visits;
use First_Party_Analytics\Utils;

/**
 * Class Database_Population.
 */
final class Database_Population {

    /**
     * For how many days to add the visits.
     */
    const DAYS_POPULATION_RANGE = 500;

    /**
     * Adds fake page visits for DB population.
     */
    public static function add_fake_page_visits_for_a_year() {
        $url             = home_url();
        $post_id         = url_to_postid( $url );
        $post_type       = get_post_type( $post_id );
        $unique_chance   = 0.3;
        $bot_chance      = 0.1;
        $internal_chance = 0.6;

        $time = time();

        $total_visits = 0;

        for ( $day_num = 0; $day_num < self::DAYS_POPULATION_RANGE; $day_num ++ ) {
            $day             = gmdate( 'Y-m-d', $time - DAY_IN_SECONDS * $day_num );
            $how_many_visits = wp_rand( 10, 50 );

            for ( $visit_num = 0; $visit_num < $how_many_visits; $visit_num ++ ) {
                Page_Visits::write(
                    $day,
                    $url,
                    $post_id,
                    $post_type,
                    Utils::get_random_float() < $unique_chance,
                    Utils::get_random_float() < $bot_chance,
                    Utils::get_random_float() < $internal_chance,
                    0
                );
                $total_visits ++;
            }
        }

        return $total_visits;
    }
}
