<?php
/**
 * Update MaxMind database upon interval.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\MaxMind;

use Exception;

/**
 * Class Update_Interval.
 */
class Update_Interval {

    /**
     * Interval hook name.
     */
    const INTERVAL_HOOK_NAME = 'first_party_analytics_update_maxmind_db';

    /**
     * Interval.
     */
    const INTERVAL = DAY_IN_SECONDS * 15;

    /**
     * Constructor.
     */
    public function __construct() {
        // Schedule the action.
        add_action( 'init', [ $this, 'schedule_interval' ] );

        // Unschedule interval action on plugin deactivation.
        register_deactivation_hook( FIRST_PARTY_ANALYTICS_FILE, [ $this, 'plugin_deactivation_handler' ] );

        // Process action.
        add_action( self::INTERVAL_HOOK_NAME, [ $this, 'update_database' ] );
    }

    /**
     * Schedules the interval action if it isn't scheduled.
     *
     * @throws Exception Exception.
     */
    public static function schedule_interval() {
        if ( ! as_next_scheduled_action( self::INTERVAL_HOOK_NAME ) ) {
            as_schedule_recurring_action(
                time(),
                self::INTERVAL,
                self::INTERVAL_HOOK_NAME
            );
        }
    }

    /**
     * Plugin deactivation handler.
     */
    public function plugin_deactivation_handler() {
        as_unschedule_all_actions( self::INTERVAL_HOOK_NAME );
    }

    /**
     * Updates the database.
     *
     * @throws Exception Exception.
     */
    public function update_database() {
        Database::get_instance()->update_database();
    }
}
