<?php
/**
 * Plugin Name: First Party Analytics AJAX Optimizer
 * Description: A plugin that helps First Party Analytics AJAX requests to work faster by deloading all plugins except for the First Party Analytics and First Party Analytics Premium for First Party Analytics AJAX requests. It was installed automatically by First Party Analytics plugin. To delete it, deactivate First Party Analytics plugin.
 * Version:     0.1.3
 *
 * @package First-Party-Analytics AJAX Optimizer
 */

if ( ! function_exists( 'str_starts_with' ) ) {
    function str_starts_with( $haystack, $needle ) {
        return 0 === strncmp( $haystack, $needle, strlen( $needle ) );
    }
}

add_filter(
    'option_active_plugins',
    function( $active_plugins ) {
        $fpa_plugin_file  = 'first-party-analytics/first-party-analytics.php';
        $fpap_plugin_file = 'first-party-analytics-premium/first-party-analytics-premium.php';

        $wc_plugin_file = 'woocommerce/woocommerce.php';

        if (
            // If FPA plugin is not active (e.g. when it was removed without deactivation), delete this MU plugin.
            ! in_array( $fpa_plugin_file, $active_plugins, true ) &&
            // This is for case when other AJAX optimizers are used, which could lead to the false-negative self-destruction of this file.
            ! isset( $_REQUEST['action'] ) 
        ) {
            @unlink( __FILE__ ); 
            return $active_plugins;
        }

        // Deloads all plugins except for the FPA and FPAP for all FPA(P) AJAX requests.
        if (
            wp_doing_ajax() &&
            array_key_exists( 'action', $_REQUEST ) && 
            str_starts_with( $_REQUEST['action'], 'first_party_analytics_' ) 
        ) {
            $cookie_names = array_keys( $_COOKIE ); // is_user_logged_in() is not available so early.

            $is_used_logged_in = false;

            foreach ( $cookie_names as $cookie_name ) {
                if ( str_starts_with( $cookie_name, 'wordpress_logged_in_' ) ) {
                    $is_used_logged_in = true;
                }
            }

            if ( $is_used_logged_in ) { // WC is used to render some tables.
                return [
                    $wc_plugin_file,
                    $fpa_plugin_file,
                    $fpap_plugin_file,
                ];
            } else {
                return [
                    $fpa_plugin_file,
                    $fpap_plugin_file,
                ];
            }
        }

        return $active_plugins;
    }
);
