<?php
/**
 * A class for the graph data retrieval.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Representation\Graphs;

use First_Party_Analytics\Databases\Time_Of_Day as DB;

/**
 * Class Weekday_Views.
 */
final class Weekday_Views {

    /**
     * Returns total aggregated views per day of the weekday.
     *
     * @return array
     */
    public static function get_data() {
        global $wpdb;

        static $results;
        if ( null === $results ) { // Cache.
            $table_name = DB::get_table_name();

            $revision_where_clause = '';
            if ( isset( $_REQUEST['fpaRevision'] ) && '' !== $_REQUEST['fpaRevision'] ) { 
                $revision = sanitize_text_field( wp_unslash( $_REQUEST['fpaRevision'] ) ); 
                $revision_where_clause = $wpdb->prepare( 'WHERE revision_id = %d', $revision );
            }

            $results = $wpdb->get_results(
                "
                SELECT
                    day_of_week, SUM(visits_count) as `visits`
                FROM 
                    $table_name
                $revision_where_clause
                GROUP 
                    BY day_of_week;
            ",
                ARRAY_A
            );
        }

        if ( ! $results ) {
            return [];
        }

        $views     = [];
        $raw_views = array_column( $results, 'visits', 'hour' );
        for ( $hour = 0; $hour < 7; $hour ++ ) {
            $views[] = isset( $raw_views[ $hour ] ) ? (int) $raw_views[ $hour ] : 0;
        }

        return $views;
    }
}
