<?php
/**
 * A class for sources table representation.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Representation\Tables;

use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\Sources as Sources_Class;

/**
 * Class Sources.
 */
final class Sources extends Table {

    /**
     * Print sources control block.
     */
    private static function print_sources_control_block() {
        ?>
        <div class="first-party-analytics-group-edit-button first-party-analytics-column">
            <div class="first-party-analytics-row">
                <?php
                submit_button(
                    __( 'Add', 'first-party-analytics' ),
                    [ 'secondary', 'first-party-analytics-add-source-group', 'ml-0', 'mr-5', 'green' ]
                );
                submit_button(
                    __( 'Rename', 'first-party-analytics' ),
                    [ 'secondary', 'first-party-analytics-rename-source-group', 'ml-0', 'mr-5', 'first-party-analytics-hidden' ]
                );
                submit_button(
                    __( 'Delete', 'first-party-analytics' ),
                    [ 'delete', 'first-party-analytics-delete-source-group', 'ml-0', 'first-party-analytics-hidden' ]
                );
                ?>
            </div>
            <div class="first-party-analytics-row">
                <?php
                submit_button(
                    __( 'Reset to default', 'first-party-analytics' ),
                    [ 'secondary', 'first-party-analytics-reset-to-default-sources', 'ml-0', 'mt-m5', 'white' ]
                );
                ?>
            </div>
        </div>
        <?php
    }

    /**
     * Print sources block.
     */
    public static function print_sources_block() {
        Sources_Class::display_sources_list();
        self::print_sources_control_block();
    }

    /**
     * Print referers children.
     *
     * @param array $sources       Sources.
     * @param array $previous_path Previous path, when going recursively, lists the names of previous elements.
     */
    public static function print_referers_children( $sources, $previous_path = [] ) {
        static $rows_count = 1;

        $source_referers = array_values(
            array_filter(
                $sources,
                function( $v, $k ) {
                    return is_int( $k );
                },
                ARRAY_FILTER_USE_BOTH
            )
        );

        $referer_num = 0;
        foreach ( $source_referers as $source_referer ) {
            ?>
            <tr data-path="<?php echo esc_attr( implode( ' / ', $previous_path ) ); ?>" data-num="<?php echo esc_attr( $referer_num ); ?>">
                <td data-type="num"><?php echo esc_attr( $rows_count ); ?></td>
                <td class="editable" data-type="name">
                    <input type="text" value="<?php echo esc_attr( $source_referer[0] ); ?>">
                </td>
                <td class="editable" data-type="referer">
                    <input type="text" value="<?php echo esc_attr( $source_referer[1] ); ?>">
                </td>
                <td>
                    <?php
                    $path_elems = [];
                    $i2         = 0;
                    foreach ( $previous_path as $path_elem ) {
                        if ( $i2 > 0 ) {
                            echo ' / ';
                        }
                        $path_elems[] = $path_elem;
                        print '<a class="group" href="#" data-path="' . esc_attr( implode( ' / ', $path_elems ) ) . '">' . esc_html( $path_elem ) . '</a>';
                        $i2++;
                    }
                    ?>
                </td>
                <td>
                    <div class="first-party-analytics-row">
                        <?php
                        submit_button(
                            __( 'Edit', 'first-party-analytics' ),
                            [ 'secondary', 'first-party-analytics-edit-source', 'ml-0', 'mr-5', 'mt-m5' ]
                        );
                        submit_button(
                            __( 'Save', 'first-party-analytics' ),
                            [ 'secondary', 'first-party-analytics-save-source', 'ml-0', 'mr-5', 'mt-m5', 'first-party-analytics-hidden', 'green' ]
                        );
                        submit_button(
                            __( 'Delete', 'first-party-analytics' ),
                            [ 'delete', 'first-party-analytics-delete-source', 'ml-0', 'mt-m5' ]
                        );
                        ?>
                    </div>
                </td>
            </tr>
            <?php
            $rows_count ++;
            $referer_num ++;
        }

        $source_groups = array_filter(
            $sources,
            function( $v, $k ) {
                return ! is_int( $k );
            },
            ARRAY_FILTER_USE_BOTH
        );

        foreach ( $source_groups as $source_group_name => $source_group_data ) {
            $current_path = array_merge( $previous_path, [ $source_group_name ] );
            self::print_referers_children( $source_group_data, $current_path );
        }
    }

    /**
     * Print table (referers block).
     */
    public static function print_table() {
        $sources = First_Party_Analytics::$options->get( 'setting-sources' );

        ?>
        <div class="first-party-analytics-table-content-block">
            <div class="first-party-analytics-table-content">
                <table>
                    <thead>
                    <tr>
                        <th>#</th>
                        <th><?php esc_html_e( 'Name', 'first-party-analytics' ); ?></th>
                        <th><?php esc_html_e( 'Referrer', 'first-party-analytics' ); ?><sup>1</sup></th>
                        <th><?php esc_html_e( 'Group', 'first-party-analytics' ); ?></th>
                        <th><?php esc_html_e( 'Manage', 'first-party-analytics' ); ?></th>
                    </tr>
                    </thead>
                    <tbody>
                        <?php self::print_referers_children( $sources ); ?>
                    </tbody>
                </table>
            </div>
            <div class="first-party-analytics-no-sources-block mt-50"><?php esc_html_e( 'No sources', 'first-party-analytics' ); ?></div>
            <div class="referers-control-block">
                <?php
                submit_button(
                    __( 'Add new', 'first-party-analytics' ),
                    [ 'secondary', 'first-party-analytics-add-source', 'green' ]
                );
                ?>
            </div>
        </div>
        <?php
    }
}
