<?php
/**
 * Dashboard recommendations widget template.
 *
 * @package First-Party-Analytics
 */

use First_Party_Analytics\First_Party_Analytics;

$are_recommendations_enabled = First_Party_Analytics::$options->get( 'setting-enable-data-sharing-and-recommendations' );

?>

<div id="widget-first-party-analytics-recommendations">
    <ul>
        <?php
        if ( $are_recommendations_enabled ) :
            ?>
        <li>
            <a class="active" href="<?php echo esc_url( admin_url( 'admin.php?page=first-party-analytics' ) ); ?>" data-chart="time">
                <?php esc_html_e( 'First Party Analytics', 'first-party-analytics' ); ?>
            </a>
        </li>
            <?php
        endif;
        ?>
        <li style="margin-left: auto;" class="<?php echo ! $are_recommendations_enabled ? 'enable-free-recommendations' : ''; ?>">
            <a href="<?php echo admin_url( 'admin.php?page=first-party-analytics-settings' ); ?>">
                <?php
                $are_recommendations_enabled ?
                    esc_html_e( 'Settings', 'first-party-analytics' ) :
                    esc_html_e( 'Enable free personalized recommendations', 'first-party-analytics' );
                ?>
            </a>
        </li>
    </ul>

    <?php
    if ( $are_recommendations_enabled ) :
        ?>

    <ul class="recommendations-list">
        <?php
        $recommendations = First_Party_Analytics::$options->get( 'first-party-analytics-recommendations' );

        if ( $recommendations ) {
            $are_there_any_hidden_recommendations = false;

            foreach ( $recommendations as $recommendation_id => $recommendation_data ) {
                // Do not show recommendations after a month.
                $is_recommendation_hidden = isset( $recommendation_data['doneAt'] ) && strtotime( $recommendation_data['doneAt'] ) < time() - MONTH_IN_SECONDS;

                $classes = [];

                if ( $recommendation_data['done'] ) {
                    $classes[] = 'checked';
                }

                if ( $is_recommendation_hidden ) {
                    $are_there_any_hidden_recommendations = true;
                    $classes[]                            = 'hidden-recommendation';
                    $classes[]                            = 'first-party-analytics-hidden';
                }

                ?>
                    <li>
                        <label class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>">
                            <input data-recommendation-id="<?php echo esc_attr( $recommendation_id ); ?>" type="checkbox"
                                <?php checked( $recommendation_data['done'] ); ?> <?php disabled( $recommendation_data['done'] ); ?>>
                            <span><?php echo $recommendation_data['info'];  ?></span>
                        </label>
                    </li>
                <?php
            }
            if ( $are_there_any_hidden_recommendations ) {
                ?>
                <ul class="show-all-recommendations-block">
                    <li>
                        <a href="#" class="show-all-recommendations-btn"><?php echo esc_attr( 'Show all recommendations' ); ?></a>
                    </li>
                </ul>
                <?php
            }
        } else {
            ?>
            <span class="no-data-yet">
                <?php esc_html_e( 'Please wait for your personal recommendations to be generated based on the collected data.', 'first-party-analytics' ); ?>
            </span>
            <?php
        }
        ?>
    </ul>

        <?php
    endif;
    ?>
</div>
