<?php
/**
 * Template for admin menu
 *
 * @package First-Party-Analytics
 */

use First_Party_Analytics\Representation\Tables\Most_Visited_Pages;
use First_Party_Analytics\Representation\Tables\Referers;
use First_Party_Analytics\Representation\Tables\Searches;
use First_Party_Analytics\Representation\Tables\Visited_Links;
use First_Party_Analytics\Representation\Tables\Sources;
use First_Party_Analytics\Representation\Tables\Pages_Performance;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\Utils;
use First_Party_Analytics\Web_Vitals;

if ( First_Party_Analytics::$premium_enabled ) {
    First_Party_Analytics_Premium\Revisions\Revisions::print_revisions_templates();
}

?>

<div class="wrap">
    <div id="first-party-analytics-plugin-container">
        <div class="first-party-analytics-loading-placeholder">
            <span class="dashicons dashicons-wordpress-alt"></span>
        </div>

        <div class="first-party-analytics-content-container">
            <h1 class="first-party-analytics-header">
                <?php esc_html_e( 'First Party Analytics', 'first-party-analytics' ); ?>
            </h1>
            <?php do_action( 'first_party_analytics_main_page_after_header_print' ); ?>

            <div class="first-party-analytics-container first-party-analytics-main-container mb-50">
                <div class="wp-plugins-core-tabs-container">
                    <div class="wp-plugins-core-tab-content" data-tab-name="general">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'General', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mb-0"><?php esc_html_e( 'Total views for the date', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-views-chart-container"></div>
                        </div>

                        <div class="fpa-logical-block pt-10">
                            <h3 class="text-align-center mb-30 mt-10"><?php esc_html_e( 'Aggregated views for the day of the week', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-graph-block">
                                <canvas class="first-party-analytics-graph" id="fpa-day-of-week-visits-graph" height="350"></canvas>
                            </div>
                        </div>

                        <div class="fpa-logical-block pt-10">
                            <h3 class="text-align-center mb-30"><?php esc_html_e( 'Aggregated views for the hour of the day', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-graph-block">
                                <canvas class="first-party-analytics-graph" id="fpa-time-of-day-visits-graph" height="350"></canvas>
                            </div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mt-30"><?php esc_html_e( 'Browser', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-row first-party-analytics-double-charts-row">
                                <div class="first-party-analytics-graph-block first-party-analytics-double-charts-handle">
                                    <canvas class="first-party-analytics-chart" id="fpa-browser-chart" height="375"></canvas>
                                </div>
                                <div class="first-party-analytics-graph-block first-party-analytics-fake-hidden">
                                    <canvas class="first-party-analytics-chart" id="fpa-browserFull-chart" height="375"></canvas>
                                </div>
                            </div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mt-30"><?php esc_html_e( 'Operating system', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-row first-party-analytics-double-charts-row">
                                <div class="first-party-analytics-graph-block first-party-analytics-double-charts-handle">
                                    <canvas class="first-party-analytics-chart" id="fpa-os-chart" height="375"></canvas>
                                </div>
                                <div class="first-party-analytics-graph-block first-party-analytics-fake-hidden">
                                    <canvas class="first-party-analytics-chart" id="fpa-osFull-chart" height="375"></canvas>
                                </div>
                            </div>
                        </div>

                        <div class="first-party-analytics-row first-party-analytics-justify-center">
                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( 'Device type', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-device-chart" height="350"></canvas>
                                </div>
                            </div>
                        </div>

                        <div class="first-party-analytics-row first-party-analytics-justify-center">
                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( 'JavaScript enabled', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-js-enabled-chart" height="350"></canvas>
                                </div>
                            </div>

                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( '"Do not track"', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-dnt-chart" height="350"></canvas>
                                </div>
                            </div>
                        </div>

                        <div class="first-party-analytics-row first-party-analytics-justify-center">
                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( 'Adblock enabled', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-adblock-chart" height="350"></canvas>
                                </div>
                            </div>

                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( 'Analytics blocked', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-analytics-blocked-chart" height="350"></canvas>
                                </div>
                            </div>
                        </div>

                        <div class="fpa-logical-block pt-30">
                            <h3 class="text-align-center mb-0"><?php esc_html_e( 'Bounce rate', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-bounce-rate-chart-container"></div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mb-0 pt-10">
                                <?php esc_html_e( 'Returning visitors', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-returning-visitors-chart-container"></div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="times">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Times', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mb-0"><?php esc_html_e( 'Average pages view time', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-average-view-time-chart-container"></div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="interaction-capabilities">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Interaction capabilities', 'first-party-analytics' ); ?></h2>

                        <div class="first-party-analytics-row first-party-analytics-justify-center">
                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( 'Touch only (smartphone, tablet)', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-touch-only-chart" height="350"></canvas>
                                </div>
                            </div>
                        </div>

                        <div class="first-party-analytics-row first-party-analytics-justify-center">
                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( 'Pointer type', 'first-party-analytics' ); ?></h3>
                                <div class="chart-description">
                                    <p>
                                        <?php _e( '<b>fine</b>: e.g. mouse, stylus', 'first-party-analytics' ); ?>
                                    </p>
                                    <p>
                                        <?php _e( '<b>coarse</b>: e.g. finger', 'first-party-analytics' ); ?>
                                    </p>
                                    <p>
                                        <?php _e( '<b>none</b>: e.g. keyboard', 'first-party-analytics' ); ?>
                                    </p>
                                </div>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-pointer-type-chart" height="350"></canvas>
                                </div>
                            </div>

                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( 'Touch support', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-touch-support-chart" height="350"></canvas>
                                </div>
                            </div>
                        </div>

                        <div class="first-party-analytics-row first-party-analytics-justify-center">
                            <div class="fpa-logical-block">
                                <h3 class="text-align-center"><?php esc_html_e( 'Interaction capabilities (Pointer type / Touch support)', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block">
                                    <canvas class="first-party-analytics-chart" id="fpa-interaction-capabilities-chart" height="350"></canvas>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="sessions">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Sessions', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mb-0 pt-10">
                                <?php esc_html_e( 'Average session duration', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-average-session-duration-chart-container"></div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mb-0 pt-10">
                                <?php esc_html_e( 'Average page views per session', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-average-page-views-per-session-chart-container"></div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mb-0 pt-10">
                                <?php esc_html_e( 'Number of sessions', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-number-of-sessions-chart-container"></div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="pages">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Pages', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center">
                                <?php esc_html_e( 'Pages', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center"
                                id="most-visited-pages-container">
                                <div class="first-party-analytics-column first-party-analytics-table-options-list m-w-100">
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block mb-30" id="first-party-analytics-date-setting-entities">
                                        <h4 class="mt-0"><?php esc_attr_e( 'Date', 'first-party-analytics' ); ?></h4>
                                        <img class="next-child-expand-button icon-img mb-15 mt-15" src="<?php echo esc_attr( FIRST_PARTY_ANALYTICS_URL . 'assets/images/filter_icon.png' ); ?>"
                                            alt="<?php esc_attr_e( 'Open / Close filter', 'first-party-analytics' ); ?>">
                                        <?php Most_Visited_Pages::print_dates(); ?>
                                    </div>
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block mb-30" id="first-party-analytics-post-type-setting-entities">
                                        <h4><?php esc_attr_e( 'Post type', 'first-party-analytics' ); ?></h4>
                                        <img class="next-child-expand-button icon-img mb-15 mt-15" src="<?php echo esc_attr( FIRST_PARTY_ANALYTICS_URL . 'assets/images/filter_icon.png' ); ?>"
                                            alt="<?php esc_attr_e( 'Open / Close filter', 'first-party-analytics' ); ?>">
                                        <?php Most_Visited_Pages::print_post_types(); ?>
                                    </div>
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block" id="first-party-analytics-visit-type-setting-entities">
                                        <h4><?php esc_attr_e( 'Visit type', 'first-party-analytics' ); ?></h4>
                                        <img class="next-child-expand-button icon-img mb-15 mt-15" src="<?php echo esc_attr( FIRST_PARTY_ANALYTICS_URL . 'assets/images/filter_icon.png' ); ?>"
                                            alt="<?php esc_attr_e( 'Open / Close filter', 'first-party-analytics' ); ?>">
                                        <?php Most_Visited_Pages::print_visit_types(); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="screen-sizes">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Screen Sizes', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center"><?php esc_html_e( 'Screen resolutions', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-graph-block">
                                <canvas class="first-party-analytics-chart" id="fpa-screen-resolution-chart" height="350"></canvas>
                            </div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center"><?php esc_html_e( 'Bootstrap breakpoints and orientations', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-graph-block">
                                <canvas class="first-party-analytics-chart" id="fpa-breakpoint-and-orientation-chart" height="350"></canvas>
                            </div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="languages">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Languages', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center"><?php esc_html_e( 'Languages', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-graph-block">
                                <canvas class="first-party-analytics-chart" id="fpa-language-chart" height="350"></canvas>
                            </div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center"><?php esc_html_e( 'Supported languages', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-graph-block">
                                <canvas class="first-party-analytics-chart" id="fpa-supported-language-chart" height="350"></canvas>
                            </div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="countries">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Countries', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mb-45"><?php esc_html_e( 'Visitors by countries', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-graph-block pl-0 pr-0">
                                <div id="fpa-countries-map-visits" class="t-overflow-hidden"></div>
                            </div>
                        </div>

                        <div class="fpa-logical-block">
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center"
                                id="countries-table-countries">
                            </div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="searches">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Searches', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <div class="first-party-analytics-graph-block">
                                <div id="fpa-searches-word-cloud"></div>
                            </div>
                        </div>

                        <div class="fpa-logical-block">
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center"
                                id="searches-table-container">
                                <div class="first-party-analytics-column first-party-analytics-table-options-list">
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block mb-30"
                                        id="first-party-analytics-search-type-setting-entities">

                                        <h4 class="mt-0"><?php esc_attr_e( 'Search type', 'first-party-analytics' ); ?></h4>
                                        <?php Searches::print_search_types(); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="visited-links">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Visited links', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center"
                                id="visited-links-table-container">
                                <div class="first-party-analytics-column first-party-analytics-table-options-list">
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block mb-30"
                                        id="first-party-analytics-visited-links-date-setting-entities">

                                        <h4 class="mt-0"><?php esc_attr_e( 'Date', 'first-party-analytics' ); ?></h4>
                                        <?php Visited_Links::print_dates(); ?>
                                    </div>
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block mb-30"
                                        id="first-party-analytics-visited-links-dst-type-setting-entities">

                                        <h4 class="mt-0"><?php esc_attr_e( 'Destination', 'first-party-analytics' ); ?></h4>
                                        <?php Visited_Links::print_destination_types(); ?>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <?php if ( First_Party_Analytics::$premium_enabled ) : ?>
                            <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Visited links', 'first-party-analytics' ); ?></h2>

                            <div class="fpa-logical-block">
                                <h3 class="text-align-center mb-45"><?php esc_html_e( 'Conversion tracking for outgoing links', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-column pl-0 pr-0 first-party-analytics-justify-content-center">
                                    <table class="first-party-analytics-conversion-tracking">
                                        <thead>
                                        <tr>
                                            <th>
                                                #
                                            </th>
                                            <th>
                                                <?php esc_attr_e( 'Domain', 'first-party-analytics' ); ?><sup>1</sup>
                                            </th>
                                            <th>
                                                <?php esc_attr_e( 'URL param', 'first-party-analytics' ); ?>
                                            </th>
                                            <th>
                                                <?php esc_attr_e( 'Param value', 'first-party-analytics' ); ?>
                                            </th>
                                            <th>
                                                <?php esc_attr_e( 'Earnings per click', 'first-party-analytics' ); ?>
                                                <?php
                                                $currency = Utils::get_currency();

                                                if ( $currency ) {
                                                    echo esc_html( '(' . $currency . ')' );
                                                }
                                                ?>
                                            </th>
                                            <th>
                                                <?php esc_attr_e( 'Clicks', 'first-party-analytics' ); ?>
                                            </th>
                                            <th>
                                                <?php esc_attr_e( 'Total earnings', 'first-party-analytics' ); ?>
                                                <?php
                                                if ( $currency ) {
                                                    echo esc_html( '(' . $currency . ')' );
                                                }
                                                ?>
                                            </th>
                                        </tr>
                                        </thead>
                                        <tbody>
                                        </tbody>
                                    </table>
                                    <div class="first-party-analytics-comment">
                                        <?php esc_html_e( 'To save the row and make it to work, you should always specify earnings per click and specify domain or URL param (if URL param value is not specified, then it applies broadly to any value).', 'first-party-analytics' ); ?>
                                        <br>
                                        <?php esc_html_e( 'Total value is calculated after you saved the row and the data has been accumulated by the formulae: earnings per click * total number of clicks on the links matching the destination (by domain, URL param, or both).', 'first-party-analytics' ); ?>
                                        <br>
                                        <br>
                                        <?php esc_html_e( '1 - Example of a valid domain: example.com or example.*', 'first-party-analytics' ); ?>
                                    </div>
                                </div>

                                <div class="first-party-analytics-column mt-30 mb-20">
                                    <?php submit_button( __( 'Save changes', 'first-party-analytics' ), [ 'primary', 'first-party-analytics-save-outgoing-links-btn' ] ); ?>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="user-agents">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'User-Agents', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center">
                                <?php esc_html_e( 'User-Agents', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center"
                                id="user-agents-table-container">
                            </div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="referers">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Referrers', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center">
                                <?php esc_html_e( 'Referrers', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center"
                                id="referers-table-container">
                                <div class="first-party-analytics-column first-party-analytics-table-options-list">
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block mb-30"
                                        id="first-party-analytics-referers-display-type-setting-entities">

                                        <h4 class="mt-0"><?php esc_attr_e( 'Display type', 'first-party-analytics' ); ?></h4>
                                        <?php Referers::print_display_types(); ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="sources">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Sources', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center">
                                <?php esc_html_e( 'Sources', 'first-party-analytics' ); ?>
                            </h3>

                            <div class="first-party-analytics-column" id="fpa-visits-by-sources-block">
                                <div class="first-party-analytics-row mt-50">
                                    <label>
                                        <select>
                                            <option value="all-time">
                                                <?php esc_html_e( 'All-time', 'first-party-analytics' ); ?>
                                            </option>
                                            <option value="7-days">
                                                <?php esc_html_e( '7 days', 'first-party-analytics' ); ?>
                                            </option>
                                            <option value="30-days">
                                                <?php esc_html_e( '30 days', 'first-party-analytics' ); ?>
                                            </option>
                                            <option value="12-weeks">
                                                <?php esc_html_e( '12 weeks', 'first-party-analytics' ); ?>
                                            </option>
                                            <option value="12-months">
                                                <?php esc_html_e( '12 months', 'first-party-analytics' ); ?>
                                            </option>
                                        </select>
                                    </label>
                                </div>

                                <div class="first-party-analytics-block">
                                    <div class="first-party-analytics-row first-party-analytics-table-container first-party-analytics-nowrap"
                                        id="fpa-sources-table-container">
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="fpa-logical-block m-hidden">
                            <h3 class="text-align-center">
                                <?php esc_html_e( 'Configure Sources', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center"
                                id="fpa-sources-management-table-container">
                                <div class="first-party-analytics-column first-party-analytics-table-options-list">
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block">
                                        <?php Sources::print_sources_block(); ?>
                                    </div>
                                </div>
                                <div class="first-party-analytics-column first-party-analytics-table-content-container">
                                    <?php Sources::print_table(); ?>
                                    <div class="first-party-analytics-row">
                                        <p class="first-party-analytics-comment">
                                            <?php esc_html_e( '1 - Example of a valid referer: example.com or example.*', 'first-party-analytics' ); ?>
                                        </p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <?php if ( First_Party_Analytics::$premium_enabled && class_exists( 'WooCommerce' ) ) : ?>
                        <div class="wp-plugins-core-tab-content" data-tab-name="woocommerce">
                            <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'WooCommerce', 'woocommerce' ); ?></h2>

                            <div class="fpa-logical-block">
                                <h3 class="text-align-center mb-45"><?php esc_html_e( 'Conversion funnel', 'first-party-analytics' ); ?></h3>
                                <div class="first-party-analytics-graph-block pl-0 pr-0 fpa-flex-justify-center inner-svg-overflow-visible" id="fpa-woo-funnel-chart-container">
                                </div>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="wp-plugins-core-tab-content" data-tab-name="performance">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Performance', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <div class="first-party-analytics-web-vitals-container">
                                <h3 class="text-align-center mb-0 first-party-analytics-web-vitals-header">
                                    <?php esc_html_e( 'Web vitals', 'first-party-analytics' ); ?>
                                    <div class="first-party-analytics-question-mark" data-content="
                                    <?php
                                        esc_attr_e(
                                            'The performance score is based on the 6 most important web metrics and ranges from 0 to 100. 
                                                Below 50 is poor, and above 90 is good. The numbers shown are for the 75 percentile visitor (i.e. 25% of visitors experience a worse performance). 
                                                The red background color shows the percentage of visitors with poor performance, the green the percentage of visitors with good performance. 
                                                The measurement date range is extended to the past if needed for getting reliable data, for example, 
                                                if there are not enough visitors for a certain day, data from the day before is appended. 
                                                Due to rounding and aggregation, the background color at the pin location might not be the same color as the number.',
                                            'first-party-analytics'
                                        );
                                        ?>
                                        ">
                                    </div>
                                </h3>

                                <div class="text-align-right mb-5 mt-30">
                                    <div class="fpa-web-vitals-control-block">
                                        <div class="fpa-web-vitals-page-block">
                                            <label>
                                                <input type="text" id="first-party-analytics-web-vitals-page-input"
                                                   placeholder="<?php esc_html_e( 'Page URL / ID (All pages by default)', 'first-party-analytics' );  ?>"
                                                   value="<?php echo isset( $_GET['web-vitals-page'] ) ? esc_attr( wp_unslash( $_GET['web-vitals-page'] ) ) : '';  ?>">
                                            </label>
                                        </div>
                                        <?php Web_Vitals::print_dates(); ?>
                                    </div>
                                </div>

                                <div class="first-party-analytics-web-vitals-blocks first-party-analytics-row">
                                    <div class="first-party-analytics-web-vitals-block first-party-analytics-column" data-web-vitals-type="desktop">
                                        <h3 class="text-align-center"><?php esc_html_e( 'Desktop', 'first-party-analytics' ); ?></h3>

                                        <div class="first-party-analytics-web-vitals-scores-content"></div>
                                        <div class="first-party-analytics-web-vitals-content"></div>
                                    </div>

                                    <div class="first-party-analytics-web-vitals-block first-party-analytics-column" data-web-vitals-type="mobile">
                                        <h3 class="text-align-center"><?php esc_html_e( 'Mobile', 'first-party-analytics' ); ?></h3>

                                        <div class="first-party-analytics-web-vitals-scores-content"></div>
                                        <div class="first-party-analytics-web-vitals-content"></div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <?php if ( First_Party_Analytics::$premium_enabled ) : ?>
                            <div class="fpa-logical-block">
                                <h3 class="text-align-center">
                                    <?php esc_html_e( 'BF cache support', 'first-party-analytics' ); ?>
                                </h3>
                                <div class="first-party-analytics-digit-block" id="first-party-analytics-progress-block">
                                </div>
                            </div>
                        <?php endif; ?>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center mb-0"><?php esc_html_e( 'Average page load time', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-average-load-time-chart-container"></div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center">
                                <?php esc_html_e( 'Pages performance', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center" id="pages-performance-table-container">
                                <div class="first-party-analytics-column first-party-analytics-table-options-list m-w-100">
                                    <div class="first-party-analytics-column first-party-analytics-setting-entities-block" data-type="date">
                                        <h4><?php esc_attr_e( 'Date', 'first-party-analytics' ); ?></h4>
                                        <?php Pages_Performance::print_dates(); ?>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <?php if ( First_Party_Analytics::$premium_enabled ) : ?>
                            <div class="fpa-logical-block">
                                <h3 class="text-align-center">
                                    <?php esc_html_e( 'Slowest loading pages', 'first-party-analytics' ); ?>
                                </h3>
                                <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center" id="slowest-loading-pages-table-container">
                                    <div class="first-party-analytics-column first-party-analytics-table-options-list m-w-100">
                                        <div class="first-party-analytics-column first-party-analytics-setting-entities-block" data-type="date">
                                            <h4><?php esc_attr_e( 'Date', 'first-party-analytics' ); ?></h4>
                                            <?php First_Party_Analytics_Premium\Representation\Tables\Slowest_Loading_Pages::print_dates(); ?>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="fpa-logical-block">
                                <h3 class="text-align-center">
                                    <?php esc_html_e( 'Slowest AJAX requests', 'first-party-analytics' ); ?>
                                </h3>
                                <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center" id="ajax-requests-table-container">
                                    <div class="first-party-analytics-column first-party-analytics-table-options-list m-w-100">
                                        <div class="first-party-analytics-column first-party-analytics-setting-entities-block" data-type="date">
                                            <h4><?php esc_attr_e( 'Date', 'first-party-analytics' ); ?></h4>
                                            <?php First_Party_Analytics_Premium\Representation\Tables\Ajax_Requests::print_dates(); ?>
                                        </div>
                                        <div class="first-party-analytics-column first-party-analytics-setting-entities-block" data-type="request-type">
                                            <h4><?php esc_attr_e( 'Request type', 'first-party-analytics' ); ?></h4>
                                            <?php First_Party_Analytics_Premium\Representation\Tables\Ajax_Requests::print_request_types(); ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>

                    <div class="wp-plugins-core-tab-content" data-tab-name="misc">
                        <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Misc', 'first-party-analytics' ); ?></h2>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center">
                                <?php esc_html_e( 'Google featured snippet highlighted text', 'first-party-analytics' ); ?>
                            </h3>
                            <div class="first-party-analytics-table-container first-party-analytics-row first-party-analytics-justify-content-center"
                                id="google-featured-snippet-highlighted-text-table-container">
                            </div>
                        </div>

                        <div class="fpa-logical-block">
                            <h3 class="text-align-center"><?php esc_html_e( 'Connection protocol', 'first-party-analytics' ); ?></h3>
                            <div class="first-party-analytics-graph-block">
                                <canvas class="first-party-analytics-chart" id="fpa-connection-protocol-chart" height="350"></canvas>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
</div>
