<?php
/**
 * Template for admin menu
 *
 * @package First-Party-Analytics
 */

use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\No_Tracking_Cookie;
use WP_Plugins_Core\Setting_Fields;
use First_Party_Analytics\MaxMind\Database as MaxMind_Database;

?>

<div class="wrap">
    <h1 class="first-party-analytics-header">
        <?php esc_html_e( 'First Party Analytics Settings', 'first-party-analytics' ); ?>
    </h1>

    <form id="first-party-analytics-settings-form">
        <div class="first-party-analytics-container first-party-analytics-align-items-flex-start">
            <div class="wp-plugins-core-tabs-container">
                <div class="wp-plugins-core-tab-content" data-tab-name="general">
                    <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'General Settings', 'first-party-analytics' ); ?></h2>

                    <?php
                    $maxmind_db_update_time = MaxMind_Database::get_instance()->get_last_update_time();

                    $home_url       = home_url();
                    $home_hostname  = wp_parse_url( $home_url, PHP_URL_HOST );
                    $home_url_is_ip = filter_var( $home_hostname, FILTER_VALIDATE_IP );

                    $settings_part_1 = [
                        [
                            'title' => __( 'Recommendations from us', 'first-party-analytics' ),
                            'type'  => 'title',
                            'desc'  => '',
                            'id'    => 'recommendations',
                        ],
                        [
                            'title' => __( 'Send daily collected aggregated data to a centralized server and download recommendations', 'first-party-analytics' ),
                            'id'    => 'enable-data-sharing-and-recommendations',
                            'desc'  => __( 'You will get regularly free personalized recommendation on how to improve the website. For this purpose anonymous aggregated data about your site and visitors will be shared with us.', 'first-party-analytics' ),
                            'value' => '1' === First_Party_Analytics::$options->get( 'setting-enable-data-sharing-and-recommendations' ) ? 'yes' : 'no',
                            'type'  => 'checkbox',
                        ],
                        [
                            'type' => 'sectionend',
                            'id'   => 'recommendations',
                        ],
                        [
                            'title' => __( 'General Settings', 'first-party-analytics' ),
                            'type'  => 'title',
                            'desc'  => '',
                            'id'    => 'settings',
                        ],
                        [
                            'title' => __( 'Decimate', 'first-party-analytics' ),
                            'id'    => 'decimate',
                            'desc'  => __( 'If decimate is 5, then each 5th (on average) visit is recorded. Useful for websites with a lot of traffic.', 'first-party-analytics' ),
                            'value' => First_Party_Analytics::$options->get( 'setting-decimate' ),
                            'type'  => 'number',
                            'css'   => 'width: 60px;',
                        ],
                        [
                            'title' => __( 'Add "ping" attribute to links', 'first-party-analytics' ),
                            'id'    => 'add-ping-attribute',
                            'desc'  => __( 'Warning: can slow down the site.<br>Best to use a full page caching plugin like Cloudflare or WPRocket with this option to retain site speed.', 'first-party-analytics' ),
                            'value' => '1' === First_Party_Analytics::$options->get( 'setting-add-ping-attribute' ) ? 'yes' : 'no',
                            'type'  => 'checkbox',
                        ],
                        [
                            'type' => 'sectionend',
                            'id'   => 'settings',
                        ],
                        [
                            'title' => __( 'Analytics Block Detection', 'first-party-analytics' ),
                            'type'  => 'title',
                            'desc'  => '',
                            'id'    => 'analytics-block-detection',
                        ],
                        [
                            'title'   => __(
                                'Domain to use for checking',
                                'first-party-analytics'
                            ),
                            'id'      => 'domain-type-to-use-for-analytics-block-detection',
                            'default' => First_Party_Analytics::$options->get( 'setting-analytics-block-detection-domain-type-to-use' ),
                            'type'    => 'radio',
                            'options' => [
                                'fpa'              => __( 'firstpartyanalytics.nl (Hosted by us, guaranteed no tracking)', 'first-party-analytics' ),
                                'own-domain'       => sprintf(
                                    /* translators: %s is a domain name. */
                                    __( 'For best results set up a CNAME from fxhpaoxqyajvmdg.%1$s to %2$s', 'first-party-analytics' ),
                                    $home_url_is_ip ? '{your.site}' : $home_hostname,
                                    $home_url_is_ip ? '{your.site}' : $home_hostname
                                ) . ': ' .
                                /* translators: %s is a domain name. */
                                sprintf(
                                    '<input name="analytics-block-detection-own-domain" type="text" style="width: 250px;" placeholder="%s" value="',
                                    $home_url_is_ip ? '{your.site}' : $home_hostname
                                ) . First_Party_Analytics::$options->get( 'setting-analytics-block-detection-own-domain' ) . '">',
                                'google-analytics' => __( 'Google Analytics (Best accuracy, but leaks some PII)', 'first-party-analytics' ),
                                'custom-domain'    => __( 'Custom domain', 'first-party-analytics' ) . ': ' .
                                    '<input name="analytics-block-detection-custom-domain" type="text" style="width: 250px;" placeholder="https://analytics.google.com"
                                                value="' . First_Party_Analytics::$options->get( 'setting-analytics-block-detection-custom-domain' ) . '">',
                            ],
                        ],
                        [
                            'type' => 'sectionend',
                            'id'   => 'analytics-block-detection',
                        ],
                        [
                            'title' => __( 'Ads Block Detection', 'first-party-analytics' ),
                            'type'  => 'title',
                            'desc'  => '',
                            'id'    => 'ads-block-detection',
                        ],
                        [
                            'title'   => __(
                                'Domain to use for checking',
                                'first-party-analytics'
                            ),
                            'id'      => 'domain-type-to-use-for-ads-block-detection',
                            'default' => First_Party_Analytics::$options->get( 'setting-ads-block-detection-domain-type-to-use' ),
                            'type'    => 'radio',
                            'options' => [
                                'fpa'           => __( 'firstpartyanalytics.nl (Hosted by us, guaranteed no tracking)', 'first-party-analytics' ),
                                'own-domain'    => sprintf(
                                    /* translators: %s is a domain name. */
                                    __( 'For best results set up a CNAME from fxhpaoxqyajvmdg.%1$s to %2$s', 'first-party-analytics' ),
                                    $home_url_is_ip ? '{your.site}' : $home_hostname,
                                    $home_url_is_ip ? '{your.site}' : $home_hostname
                                ) . ': ' .
                                /* translators: %s is a domain name. */
                                sprintf(
                                    '<input name="ads-block-detection-own-domain" type="text" style="width: 250px;" placeholder="%s" value="',
                                    $home_url_is_ip ? '{your.site}' : $home_hostname
                                ) . First_Party_Analytics::$options->get( 'setting-ads-block-detection-own-domain' ) . '">',
                                'google-ads'    => __( 'Google Ads (Best accuracy, but leaks some PII)', 'first-party-analytics' ),
                                'custom-domain' => __( 'Custom domain', 'first-party-analytics' ) . ': ' .
                                    '<input name="ads-block-detection-custom-domain" type="text" style="width: 250px;" placeholder="https://ads.google.com"
                                                value="' . First_Party_Analytics::$options->get( 'setting-ads-block-detection-custom-domain' ) . '">',
                            ],
                        ],
                        [
                            'type' => 'sectionend',
                            'id'   => 'ads-block-detection',
                        ],
                        [
                            'title' => __( 'MaxMind Geolocation', 'first-party-analytics' ),
                            'desc'  => __( 'An integration for utilizing MaxMind to do Geolocation lookups.', 'first-party-analytics' ),
                            'type'  => 'title',
                            'id'    => 'maxmind_geolocation',
                        ],
                    ];

                    $settings_part_2 = MaxMind_Database::is_wc_maxmind_integration_found() ?
                        [
                            [
                                'id'    => 'maxmind-wc-integration-found',
                                'title' => __( 'WooCommerce MaxMind Integration Found', 'first-party-analytics' ),
                                'type'  => 'html',
                                'value' => '<span class="first-party-analytics-bold">' .
                                        sprintf(
                                            /* translators: %s page URL. */
                                            __( "Please make sure it's <a href='%s'>configured</a> and the file is available.", 'first-party-analytics' ),
                                            admin_url( 'admin.php?page=wc-settings&tab=integration' )
                                        ) .
                                        '</span>',
                            ],
                        ] :
                        [
                            [
                                'id'    => 'maxmind-license-key',
                                'title' => __( 'MaxMind License Key', 'first-party-analytics' ),
                                'type'  => 'password',
                                'desc'  => sprintf(
                                /* translators: %1$s: Documentation URL */
                                    __(
                                        'The key that will be used when dealing with MaxMind Geolocation services. You can read how to generate one in <a href="%1$s">MaxMind Geolocation Integration documentation</a>.',
                                        'first-party-analytics'
                                    ),
                                    'https://woocommerce.com/document/maxmind-geolocation-integration/#section-1'
                                ),
                                'value' => First_Party_Analytics::$options->get( 'maxmind-license-key' ),
                            ],
                            [
                                'id'                => 'maxmind-database-path',
                                'title'             => __( 'Database File Path', 'first-party-analytics' ),
                                'type'              => 'text',
                                'desc'              => __(
                                    'The location that the MaxMind database should be stored.',
                                    'first-party-analytics'
                                ),
                                'value'             => MaxMind_Database::get_instance()->get_database_path(),
                                'custom_attributes' => [ 'readonly' => 'readonly' ],
                            ],
                            [
                                'id'    => 'maxmind-db-last-update-time',
                                'title' => __( 'Last Update Time', 'first-party-analytics' ),
                                'type'  => 'html',
                                'desc'  => __(
                                    'Initial download is done when you enter your license key. Then updates are performed every 15 days (if no WooCommerce MaxMind integration found).',
                                    'first-party-analytics'
                                ),
                                'value' => $maxmind_db_update_time ? date_i18n( 'F j, Y G:i', $maxmind_db_update_time ) :
                                    '<span class="first-party-analytics-red">' . __( 'Database is missing.', 'first-party-analytics' ) .
                                    '</span> ' . __( "Please enter your license key and make sure it's valid.", 'first-party-analytics' ),
                            ],
                        ];

                    $settings_part_3 = [
                        [
                            'type' => 'sectionend',
                            'id'   => 'maxmind_geolocation',
                        ],
                    ];

                    Setting_Fields::output_fields( array_merge( $settings_part_1, $settings_part_2, $settings_part_3 ) );
                    ?>
                </div>
                <div class="wp-plugins-core-tab-content" data-tab-name="exclude-by-cookie">
                    <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Exclude by Cookie', 'first-party-analytics' ); ?></h2>
                    <div class="first-party-analytics-column first-party-analytics-align-items-flex-start">
                        <?php
                        $settings = [
                            [
                                'title' => __( 'Exclude by Cookie', 'first-party-analytics' ),
                                'type'  => 'title',
                                'desc'  => __( 'Do not track the users with one of the following cookies. If the value is empty, excludes the user with any cookie value.', 'first-party-analytics' ),
                                'id'    => 'exclude-by-cookie',
                            ],
                            [
                                'type' => 'sectionend',
                                'id'   => 'exclude-by-cookie',
                            ],
                        ];

                        Setting_Fields::output_fields( $settings );
                        ?>

                        <table class="first-party-analytics-cookies mb-1em">
                            <thead>
                            <tr>
                                <th><?php esc_html_e( 'Cookie #', 'first-party-analytics' ); ?></th>
                                <th><?php esc_html_e( 'Name', 'first-party-analytics' ); ?></th>
                                <th><?php esc_html_e( 'Value', 'first-party-analytics' ); ?></th>
                            </tr>
                            </thead>
                            <tbody>
                            </tbody>
                        </table>

                        <div class="first-party-analytics-row mt-10 mb-10">
                            <p class="first-party-analytics-comment">
                                <?php esc_html_e( '* - To delete a row, just delete the name and value (from the bottom); or delete the name and save.', 'first-party-analytics' ); ?>
                            </p>
                        </div>

                        <?php
                        $settings = [
                            [
                                'title' => __( 'No-tracking cookie', 'first-party-analytics' ),
                                'type'  => 'title',
                                'desc'  => __( 'The plugin will not record your browser when there is an injected no-tracking cookie in your browser.', 'first-party-analytics' ),
                                'id'    => 'exclude-by-cookie',
                            ],
                            [
                                'type' => 'sectionend',
                                'id'   => 'exclude-by-cookie',
                            ],
                        ];

                        Setting_Fields::output_fields( $settings );
                        ?>

                        <p class="first-party-analytics-no-tracking-cookie-status-block mt-0 mb-5 first-party-analytics-text-bold">
                        <span>
                            <?php esc_html_e( 'Current status:', 'first-party-analytics' ); ?>
                        </span>
                            <span class="first-party-analytics-no-tracking-cookie-value">
                            <?php echo No_Tracking_Cookie::get_current_status_html();  ?>
                        </span>
                        </p>

                        <?php echo No_Tracking_Cookie::get_current_status_button_html();  ?>
                    </div>
                </div>
                <div class="wp-plugins-core-tab-content" data-tab-name="exclude-by-ip">
                    <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Exclude by IP', 'first-party-analytics' ); ?></h2>

                    <?php
                    $settings = [
                        [
                            'title' => __( 'Exclude by IP', 'first-party-analytics' ),
                            'type'  => 'title',
                            'desc'  => __(
                                'Do not track the users with one of the following IPs. 

                            1. You can specify IP or a range (subnet). 
                            1.1. Ranges can be specified in CIDR format (like <code>::1/128</code> or <code>127.0.0.1/32</code>) and in pattern format (like <code>::*:*</code> or <code>127.0.*.*</code>).
                            2. Supports IPv4 and IPv6 IPs and ranges.',
                                'first-party-analytics'
                            ),
                            'id'    => 'exclude-by-ip',
                        ],
                        [
                            'type' => 'sectionend',
                            'id'   => 'exclude-by-ip',
                        ],
                    ];

                    Setting_Fields::output_fields( $settings );
                    ?>

                    <div class="first-party-analytics-column first-party-analytics-align-items-flex-start mt-20">
                    <textarea id="first-party-analytics-exclusion-ips" rows="10" placeholder=
"127.0.0.1
127.0.0.1/32
::1/128
127.0.0.1/32
::*:*
127.0.*.*"
                    ><?php 
                        echo implode( "\n", First_Party_Analytics::$options->get( 'setting-exclusion-ips' ) ); 
                    ?>
                    </textarea>
                        <?php submit_button( __( 'Paste my IP', 'first-party-analytics' ), [ 'secondary', 'first-party-analytics-paste-my-ip', 'mt-30', 'ml-0' ] ); ?>

                        <div class="first-party-analytics-row mt-30 mb-10">
                            <p class="first-party-analytics-comment">
                                <?php esc_html_e( '* - Use a new-line to separate IPs.', 'first-party-analytics' ); ?>
                            </p>
                        </div>
                    </div>
                </div>
                <div class="wp-plugins-core-tab-content" data-tab-name="cache">
                    <h2 class="wp-plugins-core-tab-heading"><?php esc_html_e( 'Cache', 'first-party-analytics' ); ?></h2>

                    <?php
                    $settings = [
                        [
                            'title' => __( 'Cache', 'first-party-analytics' ),
                            'type'  => 'title',
                            'desc'  => '',
                            'id'    => 'cache',
                        ],
                        [
                            'title' => __( "Use object cache, when it's available:", 'first-party-analytics' ),
                            'id'    => 'use-object-cache',
                            'value' => '1' === First_Party_Analytics::$options->get( 'setting-use-object-cache' ) ? 'yes' : 'no',
                            'type'  => 'checkbox',
                        ],
                        [
                            'type' => 'sectionend',
                            'id'   => 'cache',
                        ],
                    ];

                    Setting_Fields::output_fields( $settings );
                    ?>
                </div>
                <?php do_action( 'first_party_analytics_admin_menu_settings_tabs_printed' ); ?>
            </div>
        </div>
        <hr>
        <div class="first-party-analytics-container">
            <div class="first-party-analytics-column mt-m20 mb-20">
                <?php submit_button( __( 'Save changes', 'first-party-analytics' ), [ 'primary', 'first-party-analytics-submit' ] ); ?>
            </div>
        </div>
        <div class="first-party-analytics-container">
            <div class="first-party-analytics-row first-party-analytics-justify-center">
                <a class="first-party-analytics-link first-party-analytics-export-settings-link"><?php esc_html_e( 'Export Settings', 'first-party-analytics' ); ?></a>
                <a class="first-party-analytics-link first-party-analytics-import-settings-link"><?php esc_html_e( 'Import Settings', 'first-party-analytics' ); ?></a>
                <input type="file" name="first-party-analytics-import-settings-link-file-input" accept="application/JSON">
            </div>
            <div class="first-party-analytics-row first-party-analytics-justify-center">
                <a class="first-party-analytics-link first-party-analytics-reset-settings-link mt-15"><?php esc_html_e( 'Reset All Settings', 'first-party-analytics' ); ?></a>
            </div>
            <div class="first-party-analytics-container">
                <div class="first-party-analytics-row">
                    <a class="first-party-analytics-link first-party-analytics-show-debug-data-link mt-15">
                        <?php esc_html_e( 'Show debug data', 'first-party-analytics' ); ?>
                    </a>
                </div>
            </div>
        </div>
    </form>
</div>
