<?php
/**
 * Client-side (JS) analytics data recording of post-visit data (when user finished viewing the page).
 *
 * Contains the data like:
 *
 * - Page load time;
 * - View time.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Tracking;

use Exception;
use First_Party_Analytics\Fields_Mapping;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\GeoLocation;
use First_Party_Analytics\Utils;

/**
 * Class Client_Side_Post_Visit.
 */
final class Client_Side_Post_Visit {

    /**
     * The name of the type of analytics.
     *
     * @var string
     */
    const NAME = 'client_side_post_visit_analytics';

    /**
     * Fields of this type of analytics.
     */
    const FIELDS = [
        'time',
        'id',
        'ip',
        'post_id',
        'postRevisionId',
        'revisionId',
        'url',
        'loadTime',
        'viewTime',
        'decimate',
        'postType',
        'adblockActive',
        'analyticsBlocked',
        'cookies',
        'viewedProducts',
        'bounced',
        'assetLessPageSize',
        'websiteDataDownloadSize',
        'isMobileDevice',
        // 1. Values with a separate counter that can potentially be null, and when so, are not written to the DB.
        // 1.1. Web vitals.
        'TTFB',
        'FCP',
        'LCP',
        'FID',
        'CLS',
        'INP',
        'SI',
        'TBT',
        'TTI',
        'webVitalsScore',
        // 1.2. Misc.
        'viewportCompletedLoadingTime',
        'bfCachePresent',
    ];

    /**
     * Add one server-side analytics entity.
     *
     * @param array $user_data User data sent by the client (along with a few server-side fields like time and IP).
     *
     * @throws Exception Exception.
     */
    public static function record( $user_data ) {
        Fields_Mapping::write(
            self::NAME,
            gmdate( 'c' ),
            $user_data['id'],
            GeoLocation::get_visitor_ip(),
            $user_data['postId'],
            $user_data['postRevisionId'],
            First_Party_Analytics::$premium_enabled ? \First_Party_Analytics_Premium\Revisions\Revisions::get_current_revision_id() : 0,
            Utils::standardize_url( $user_data['pageUrl'] ),
            $user_data['loadTime'],
            $user_data['viewTime'],
            $user_data['decimate'],
            $user_data['postType'],
            $user_data['adblockActive'],
            $user_data['analyticsBlocked'],
            $_COOKIE,
            $user_data['viewedProducts'],
            $user_data['bounced'],
            $user_data['assetLessPageSize'],
            $user_data['websiteDataDownloadSize'],
            $user_data['isMobileDevice'],
            $user_data['TTFB'],
            $user_data['FCP'],
            $user_data['LCP'],
            $user_data['FID'],
            $user_data['CLS'],
            $user_data['INP'],
            $user_data['SI'],
            $user_data['TBT'],
            $user_data['TTI'],
            $user_data['webVitalsScore'],
            $user_data['viewportCompletedLoadingTime'],
            $user_data['bfCachePresent']
        );
    }
}
