<?php
/**
 * Client-side (JS) analytics data recording.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Tracking;

use Exception;
use First_Party_Analytics\Fields_Mapping;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\GeoLocation;
use First_Party_Analytics\Utils;

/**
 * Class Client_Side.
 */
final class Client_Side {

    /**
     * The name of the type of analytics.
     *
     * @var string
     */
    const NAME = 'client_side_analytics';

    /**
     * Fields of this type of analytics.
     */
    const FIELDS = [
        'time',
        'id',
        'ip',
        'revisionId',
        'screenResolution',
        'timezone',
        'deviceMemory',
        'hardwareConcurrency',
        'language',
        'maxTouchPoints',
        'userAgent',
        'doNotTrack',
        'pageTitle',
        'connectionProtocol',
        'post_id',
        'url',
        'referer',
        'decimate',
        'postType',
        'textFragment',
        'searchText',
        'isDeviceTouchOnly',
        'languages',
        'breakpointAndOrientation',
        'dnt',
        'cookies',
        'pointerType',
        'hasTouch',
    ];

    /**
     * Add one server-side analytics entity.
     *
     * @param array $user_data User data sent by the client (along with a few server-side fields like time and IP).
     *
     * @throws Exception Exception.
     */
    public static function record( $user_data ) {
        Fields_Mapping::write(
            self::NAME,
            gmdate( 'c' ),
            $user_data['id'],
            GeoLocation::get_visitor_ip(),
            First_Party_Analytics::$premium_enabled ? \First_Party_Analytics_Premium\Revisions\Revisions::get_current_revision_id() : 0,
            $user_data['screenResolution'],
            $user_data['timezone'],
            $user_data['deviceMemory'],
            $user_data['hardwareConcurrency'],
            $user_data['language'],
            $user_data['maxTouchPoints'],
            $user_data['userAgent'],
            $user_data['doNotTrack'],
            $user_data['pageTitle'],
            $user_data['connectionProtocol'],
            $user_data['postId'],
            Utils::standardize_url( $user_data['pageUrl'] ),
            $user_data['referer'],
            $user_data['decimate'],
            $user_data['postType'],
            $user_data['textFragment'],
            $user_data['searchText'],
            $user_data['isDeviceTouchOnly'],
            $user_data['languages'],
            $user_data['breakpointAndOrientation'],
            $user_data['dnt'],
            $_COOKIE,
            $user_data['pointerType'],
            $user_data['hasTouch']
        );
    }
}
