<?php
/**
 * A class for handling searches tracking.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Tracking;

use Exception;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\GeoLocation;
use First_Party_Analytics\Requests_Exclusion;
use First_Party_Analytics\Tracking_Cookies;
use First_Party_Analytics\Databases\Search_Words as Search_Words_DB;

/**
 * Class Searches.
 */
final class Searches {

    /**
     * Returns request with the specified fields.
     *
     * @param string $search_text Search text.
     * @param string $page        Page URL on which the search has been triggered.
     * @param string $selector    Selector of the search input that triggered the search.
     * @param int    $timestamp   Timestamp of the request.
     *
     * @return array Request.
     */
    private static function get_request( $search_text, $page, $selector, $timestamp ) {
        return [
            'ip'         => GeoLocation::get_visitor_ip(),
            'cookies'    => $_COOKIE,
            'searchText' => $search_text,
            'page'       => $page,
            'selector'   => $selector,
            'time'       => $timestamp,
            'revisionId' => First_Party_Analytics::$premium_enabled ? \First_Party_Analytics_Premium\Revisions\Revisions::get_current_revision_id() : 0,
        ];
    }

    /**
     * Add one searches analytics entity.
     *
     * @param string $search_text Search text.
     * @param string $page        Page URL on which the search has been triggered.
     * @param string $selector    Selector of the search input that triggered the search.
     * @param int    $timestamp   Timestamp of the request.
     *
     * @throws Exception Exception.
     */
    public static function handle( $search_text, $page, $selector, $timestamp ) {
        $requests = Requests_Exclusion::exclude( [ self::get_request( $search_text, $page, $selector, $timestamp ) ] );
        if ( $requests ) {
            $request = $requests[0];
            $time    = gmdate( 'Y-m-d H:i:s', $request['time'] );
            Search_Words_DB::handle_search( $request['searchText'], $request['page'], $request['selector'], $time, $request['revisionId'] );
        }
    }
}
