<?php
/**
 * Tracking when user has JS disabled.
 *
 * Uses server-side analytics tracking class.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\Tracking;

use Exception;
use First_Party_Analytics\First_Party_Analytics;
use First_Party_Analytics\Utils;

/**
 * Class Noscript.
 */
final class Server_Side_NoScript {

    /**
     * The name of the type of analytics.
     *
     * @var string
     */
    const NAME = 'server_side_noscript_analytics';

    /**
     * Fields of this type of analytics.
     *
     * @important should be at sync with noscript-tracker.php.
     */
    const FIELDS = [
        'time',
        'id',
        'ip',
        'post_id',
        'url',
        'requestMethod',
        'userAgent',
        'referer',
        'decimate',
        'postType',
        'searchText',
        'country',
        'dnt',
        'cookies',
        'revisionId',
    ];

    /**
     * URL of the noscript tracking image.
     *
     * @var string
     */
    public static $noscript_tracking_image_path;

    /**
     * Constructor.
     *
     * @throws Exception Exception.
     */
    public function __construct() {
        self::$noscript_tracking_image_path = FIRST_PARTY_ANALYTICS_URL . 'src/standalone-scripts/noscript-tracker.php';

        if ( ! is_admin() ) {
            add_action( 'wp_body_open', [ $this, 'add_noscript_tracking_image_to_body' ] );
        }
    }

    /**
     * Adds fake noscript tracking image to body.
     *
     * @throws Exception Exception.
     */
    public function add_noscript_tracking_image_to_body() {
        $src = self::$noscript_tracking_image_path;

        if ( is_search() ) {
            $search_query = get_search_query();
            $src          = Utils::add_url_param( $src, 'searchText', $search_query );
        }

        $src = Utils::add_url_param(
            $src,
            'revisionId',
            First_Party_Analytics::$premium_enabled ? \First_Party_Analytics_Premium\Revisions\Revisions::get_current_revision_id() : 0
        );

        echo "<noscript><img src='$src' style='position:absolute;opacity:0' width=1 height=1></noscript>";
    }
}
