<?php
/**
 * A class for the pages' WooCommerce tracking data.
 *
 * @package First-Party-Analytics
 */

namespace First_Party_Analytics\WooCommerce;

use First_Party_Analytics\Utils;

/**
 * Class Pages_Tracking_Data.
 */
final class Pages_Tracking_Data {

    /**
     * Meta key for page conversion depth.
     */
    const CONVERSION_DEPTH_META_KEY = 'first-party-analytics-avg-conversion-depth';

    /**
     * Meta key for page conversion value
     *
     * Suffixed by the currency - and then by the current revision, obviously (like all other meta-tracking keys).
     */
    const CONVERSIONS_VALUE_META_KEY = 'first-party-analytics-conversions-value';

    /**
     * Returns the average conversion depth of the page for representation.
     *
     * @param int $page_id ID of the page.
     *
     * @return float|string Value or "-" if no value.
     */
    public static function get_average_conversion_depth( $page_id ) {
        $revision = isset( $_REQUEST['fpaRevision'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['fpaRevision'] ) ) : ''; 

        $meta = get_post_meta( $page_id, self::CONVERSION_DEPTH_META_KEY . $revision, true );
        return $meta ? (float) $meta[1] : '-';
    }

    /**
     * Returns the page conversion value for representation.
     *
     * @param int $page_id ID of the page.
     *
     * @return float|string Value or "-" if no value.
     */
    public static function get_conversions_value( $page_id ) {
        $revision = isset( $_REQUEST['fpaRevision'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['fpaRevision'] ) ) : ''; 

        $meta = get_post_meta( $page_id, self::CONVERSIONS_VALUE_META_KEY . $revision . '-' . strtolower( Utils::get_currency() ), true );
        return $meta ? (float) $meta : '-';
    }

    /**
     * Get the page all tracking data.
     *
     * @param int $page_id ID of the page.
     *
     * @return array
     */
    public static function get_all( $page_id ) {
        return [
            'avgConversionDepth' => self::get_average_conversion_depth( $page_id ),
            'conversionsValue'   => self::get_conversions_value( $page_id ),
        ];
    }
}
